<?php
use \GeoDigs\API as API;
use \GeoDigs\CustomSearches as CustomSearches;

// wp_enqueue_script( 'geodigs_update_api_on_save', GD_DIR_ADMIN_ASSETS . 'js/featured-listings.js', array( 'jquery', 'jquery-ui-core', 'jquery-ui-sortable' ), null, true );

if( !class_exists( 'WP_List_Table' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class GD_Featured_Listings_Table extends WP_List_Table {

	function __construct() {
		global $status, $page;

		//Set parent defaults
		parent::__construct( array(
			'singular'  => 'group',     //singular name of the featured group records
			'plural'    => 'groups',    //plural name of the featured group records
			'ajax'      => false        //does this table support ajax?
		) );

	}

	function column_default( $item, $column_name ) {
		switch( $column_name ) {
			case 'display_count':
				return $item->displayCount;
			case 'sort':
				return empty( $item->sort->readable ) ? 'None' : $item->sort->readable;
			default:
				return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	function column_name( $item ) {
		//Build row actions
		$actions = array(
			'edit'      => sprintf( '<a href="?page=%s&view=%s&id=%s">Edit</a>', $_REQUEST['page'], 'form-edit', $item->id ),
			'delete'    => sprintf( '<a href="?page=%s&action=%s&id=%s">Delete</a>', $_REQUEST['page'], 'delete', $item->id ),
		);

		//Return the title contents
		return sprintf( '%1$s%2$s',
			/*$1%s*/ $item->name,
			/*$2%s*/ $this->row_actions( $actions )
		);
	}

	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			/*$1%s*/ $this->_args['singular'],  //Let's simply repurpose the table's singular label ( "movie" )
			/*$2%s*/ $item->id                //The value of the checkbox should be the record's id
		);
	}

    function column_shortcode( $item ) {
        $id = 'cs-' . $item->id;
        $text = sprintf(
			'[gd_custom_search id="%1$s"]',
			/*$1%s*/ $item->id
		);
        $actions = array(
            'edit' => sprintf(
                '<a href="#" class="gd-copy-shortcode" data-target="%s">Copy</a>', '#' . $id
            ),
        );

        return sprintf(
            '<span id="%s">%s</span>%s',
            $id, $text, $this->row_actions( $actions )
        );
	}

	function get_columns() {
		$columns = array(
			'cb'           => '<input type="checkbox" />', //Render a checkbox instead of text
			'name'         => 'Name',
			'display_count' => 'Listings Count',
			'sort'         => 'Sort',
			'shortcode'    => 'Shortcode',
		);
		return $columns;
	}

	function get_bulk_actions() {
		$actions = array(
			'delete' => 'Delete'
		);
		return $actions;
	}

	function process_bulk_action() {
		// Detect when a bulk action is being triggered...
        if( 'delete' === $this->current_action() ) {
            $searches = $_POST['group'];
            foreach ( $searches as $search_id ) {
                CustomSearches::delete( $search_id );
            }
			settings_errors();
		}
	}

	public function single_row( $item ) {
		static $row_class = '';
		$row_class = ( $row_class == '' ? ' class="alternate"' : '' );

		echo '<tr id="' . $item->id . '" ' . $row_class . '>';
		$this->single_row_columns( $item );
		echo '</tr>';
	}

	function prepare_items() {
		/**
		 * First, lets decide how many records per page to show
		 */
		$per_page = 10;

		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();

		$this->_column_headers = array( $columns, $hidden, $sortable );

		$this->process_bulk_action();

		$data = (array) API::call( 'GET', 'searches/custom' );

		$current_page = $this->get_pagenum();

		$total_items = count( $data );

		$data = array_slice( $data, (( $current_page-1 ) * $per_page ), $per_page );

		$this->items = $data;

		$this->set_pagination_args( array(
			'total_items' => $total_items,                  //WE have to calculate the total number of items
			'per_page'    => $per_page,                     //WE have to determine how many items to show on a page
			'total_pages' => ceil( $total_items/$per_page )   //WE have to calculate the total number of pages
		) );
	}


}

/** Create table of currently featured listings **/

//Create an instance of our package class...
$featured_listings_table = new GD_Featured_Listings_Table();
// //Fetch, prepare, sort, and filter our data...
$featured_listings_table->prepare_items();
// // Display our data
$featured_listings_table->display();
