<?php
namespace GeoDigs\Admin\Settings;

/**
 * GeoDigs custom searches settings
 */
class CustomSearches extends Settings
{
	public function add_submenus() {
		add_submenu_page(
			GD_ADMIN_PAGE,
			'GeoDigs Custom Searches',
			'Custom Searches',
			'manage_options',
			GD_ADMIN_PAGE_CUSTOM_SEARCHES,
			array( &$this, 'render_page' )
		);
	}
	public function display_notices() {
		settings_errors( GD_OPTIONS_CUSTOM_SEARCHES );
	}

	public function register_settings() {}

	public function render_page() {
		// If "paged" is set then we are in the table view and we don't want to
		// change that or try to update a search
		if ( isset( $_GET['paged'] ) ) {
			unset( $_GET['action'] );
			unset( $_GET['id'] );
			unset( $_GET['view'] ); // The view defaults to table so we are OK to do this
		}

		$id         = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : null;
		$action     = isset( $_GET['action'] ) ? $_GET['action'] : null;
		$view       = isset( $_GET['view'] ) ? $_GET['view'] : 'table';
		$create_url = add_query_arg( array(
			'view'   => 'form-new',
            'action' => false,
            'id'     => false,
		) );

		switch ( $action ) {
			case 'add':
                $data = gd_convert_post_to_custom_search_data();
				$added = \GeoDigs\CustomSearches::add( $data );
				if ( $added ) {
                    $view = 'form-edit';
                    $id = $added->id;
				} else {
					$view = 'form-new';
				    $search = $data;
                }
				break;

			case 'edit':
                $updated = \GeoDigs\CustomSearches::update( $id );
				$view = 'form-edit';
				$search = $_POST;
				break;

			case 'delete':
				\GeoDigs\CustomSearches::delete( $id );
				break;

			default:
				break;
		}

		// Display our messages
		settings_errors( GD_OPTIONS_CUSTOM_SEARCHES );

		switch ( $view ) {
		 case 'form-edit':
			 $search = \GeoDigs\CustomSearches::get( $id );
			 // Flow into form-new
		 case 'form-new':
			 wp_enqueue_script( 'gd_admin_custom_search_form' );
			 require_once GD_DIR_ADMIN_INCLUDES . '/custom-search-form.php';
			 break;

		 case 'table':
         default:
            echo '<form method="post">';
		    require_once GD_DIR_ADMIN_INCLUDES . '/custom-searches-table.php';
            echo '<a href="' . $create_url . '" class="button button-primary">Add New</a>';
            echo '</form>';
	    }
	}
}
