<?php
namespace GeoDigs\Admin\Settings;

use GeoDigs\API as API;

/**
 * GeoDigs general settings
 */
class General extends Settings
{
    public function __construct() {
        parent::__construct();

        $this->options = array(
            GD_OPTIONS_GENERAL         => gd_get_option( GD_OPTIONS_GENERAL ),
            GD_OPTIONS_OUR_LISTINGS    => gd_get_option( GD_OPTIONS_OUR_LISTINGS ),
            GD_OPTIONS_ADVANCED_SEARCH => gd_get_option( GD_OPTIONS_ADVANCED_SEARCH ),
            GD_OPTIONS_SOCIAL_MEDIA    => gd_get_option( GD_OPTIONS_SOCIAL_MEDIA ),
            GD_OPTIONS_GOOGLE_MAPS     => gd_get_option( GD_OPTIONS_GOOGLE_MAPS ),
            GD_OPTIONS_URLS            => gd_get_option( GD_OPTIONS_URLS ),
        );

        // This is stored here to prevent calling the API multiple times on this pages
        $this->listing_types = API::call( 'GET', 'listings/types' );
    }

    public function add_submenus() {
        add_submenu_page(
            GD_ADMIN_PAGE,
            'GeoDigs General',
            'General',
            'manage_options',
            GD_ADMIN_PAGE,
            array( &$this, 'render_page' )
        );
    }
    public function display_notices() {
        settings_errors( GD_ADMIN_PAGE );
    }

    public function register_settings() {
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_GOOGLE_MAPS,
            array( &$this, 'validate_google_maps_options' )
        );
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_GENERAL,
            array( &$this, 'validate_general_options' )
        );
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_OUR_LISTINGS,
            array( &$this, 'validate_our_listings_options' )
        );
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_ADVANCED_SEARCH,
            array( &$this, 'validate_advanced_search_options' )
        );
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_SOCIAL_MEDIA,
            array( &$this, 'validate_facebook_options' )
        );
        register_setting(
            GD_OPTIONS_GENERAL,
            GD_OPTIONS_URLS,
            array( &$this, 'validate_url_options' )
        );

        // Google Maps
        add_settings_section(
            GD_ADMIN_SECTION_GOOGLE_MAPS,
            'Google Maps',
            '',
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'api_key',
            '*Google Maps API Key',
            array( &$this, 'render_google_maps_api_key_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_GOOGLE_MAPS
        );

        // Layout
        add_settings_section(
            'layout',
            'Layout and Behavior',
            '',
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'listings_layout',
            'Listing Results Layout',
            array( &$this, 'render_listing_layout_input' ),
            GD_ADMIN_PAGE,
            'layout'
        );
        add_settings_field(
            'listings_per_page',
            'Listings per page',
            array( &$this, 'render_listings_per_page_input' ),
            GD_ADMIN_PAGE,
            'layout'
        );
        add_settings_field(
            'hide_login_links',
            'Hide Login Links in the main menu',
            array( &$this, 'render_hide_login_links_input' ),
            GD_ADMIN_PAGE,
            'layout'
        );
        add_settings_field(
            'max_listing_details_view_count',
            'Max Listing Detail page views before login required',
            array( &$this, 'render_listing_detail_view_count_input' ),
            GD_ADMIN_PAGE,
            'layout'
        );
        add_settings_field(
            'more_info_email',
            'Email for More Information Requests',
            array( &$this, 'render_more_info_email' ),
            GD_ADMIN_PAGE,
            'layout'
        );

        // Our listings
        add_settings_section(
            GD_ADMIN_SECTION_OUR_LISTINGS,
            'Our Listings',
            '',
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'listings_to_display',
            'Listings to Display',
            array( &$this, 'render_listings_to_display_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_OUR_LISTINGS
        );
        add_settings_field(
            'source',
            'Primary MLS Source',
            array( &$this, 'render_primary_source_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_OUR_LISTINGS
        );
        add_settings_field(
            'type',
            'Listings Type',
            array( &$this, 'render_our_listings_type_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_OUR_LISTINGS
        );

        // Advanced search
        add_settings_section(
            GD_ADMIN_SECTION_ADVANCED_SEARCH,
            'Advanced Search',
            '',
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'type',
            'Default Listings Type',
            array( &$this, 'render_advanced_search_type_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_ADVANCED_SEARCH
        );
        add_settings_field(
            'custom_cities',
            'Available cities for "City" field',
            array( &$this, 'render_custom_cities_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_ADVANCED_SEARCH
        );
        add_settings_field(
            'map_search_start',
            'Starting Latitude, Longitude, and Zoom Level for the map search',
            array( &$this, 'render_map_search_start_inputs' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_ADVANCED_SEARCH
        );
        
        // Social Media 
        add_settings_section(
            GD_ADMIN_SECTION_SOCIAL_MEDIA,
            'Social Media',
            '',
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'api_key',
            'Facebook App ID',
            array( &$this, 'render_facebook_app_id_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_SOCIAL_MEDIA
        );
        
        // URLs 
        add_settings_section(
            GD_ADMIN_SECTION_URLS,
            'URLs',
            array( &$this, 'render_section_urls' ),
            GD_ADMIN_PAGE
        );
        add_settings_field(
            'listings_prefix',
            '*Listings Prefix',
            array( &$this, 'render_urls_listings_prefix_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'account_prefix',
            '*Account Prefix',
            array( &$this, 'render_urls_account_prefix_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'favorites_prefix',
            '*Favorites Prefix',
            array( &$this, 'render_urls_favorites_prefix_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'proxy_api',
            '*Proxy API',
            array( &$this, 'render_urls_proxy_api_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'document_store',
            '*Document Store',
            array( &$this, 'render_urls_document_store_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'home_worth',
            '*Home Worth',
            array( &$this, 'render_urls_home_worth_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
        add_settings_field(
            'listing_alerts',
            '*Listing Alerts',
            array( &$this, 'render_urls_listing_alerts_input' ),
            GD_ADMIN_PAGE,
            GD_ADMIN_SECTION_URLS
        );
    }

    public function render_page() { ?>
        <form method="post" action="options.php">
                    <p class="bg-info">
                        NOTE: <small>Fields prefixed with a "*" are required</small>
                    </p>
            <?php
            settings_fields( GD_OPTIONS_GENERAL );
            do_settings_sections( GD_ADMIN_PAGE );
            submit_button();
            ?>
        </form>
    <?php }

    ////////////////////
    // Layout options //
    ////////////////////

    public function render_listing_layout_input() {
        $layout_rows = 'rows';
        $layout_grid = 'grid';
        $name = GD_OPTIONS_GENERAL . '[ListingsLayout]';
        $value = isset( $this->options[GD_OPTIONS_GENERAL]['ListingsLayout'] )
            ? $this->options[GD_OPTIONS_GENERAL]['ListingsLayout']
            : $layout_rows;
        ?>
        <div class="layout row">
            <div class="col-md-3">
                <div class="radio">
                    <label>
                        <span>Rows</span>
                        <input type="radio" name="<?php echo $name; ?>" value="<?php echo $layout_rows; ?>" <?php checked( $value, $layout_rows ); ?>>
                        <img src="<?php echo GD_URL_ADMIN_ASSETS_IMAGES; ?>layout-rows.png" alt="Row Layout">
                    </label>
                </div>
            </div>
            <div class="col-md-3">
                <div class="radio">
                    <label>
                        <span>Grid</span>
                        <input type="radio" name="<?php echo $name; ?>" value="<?php echo $layout_grid; ?>" <?php checked( $value, $layout_grid ); ?>>
                        <img src="<?php echo GD_URL_ADMIN_ASSETS_IMAGES; ?>layout-grid.png" alt="Grid Layout">
                    </label>
                </div>
            </div>
        </div>
    <?php }
    
    public function render_listings_per_page_input() {
        $name = GD_OPTIONS_GENERAL . '[ListingsPerPage]';
        $value = isset( $this->options[GD_OPTIONS_GENERAL]['ListingsPerPage'] ) ? $this->options[GD_OPTIONS_GENERAL]['ListingsPerPage'] : 10;
        echo '<input type="number" name="' . $name . '" value="' . $value . '">';
    }

    public function render_hide_login_links_input() {
        $name = GD_OPTIONS_GENERAL . '[HideLoginLinks]';
        $value = isset( $this->options[GD_OPTIONS_GENERAL]['HideLoginLinks'] )
            ? $this->options[GD_OPTIONS_GENERAL]['HideLoginLinks'] : '0';
        echo '<input type="checkbox" name="' . $name . '" ' . checked( $value, '1', false ) . ' value="1">';
    }

    public function render_listing_detail_view_count_input() {
        $name = GD_OPTIONS_GENERAL . '[MaxDetailViews]';
        $value = isset( $this->options[GD_OPTIONS_GENERAL]['MaxDetailViews'] )
            ? $this->options[GD_OPTIONS_GENERAL]['MaxDetailViews'] : 5;
        echo '<input type="number" name="' . $name . '" value="' . $value .'">';
    }
    
    public function render_more_info_email() {
        $name = GD_OPTIONS_GENERAL . '[MoreInfoEmail]';
        $value = isset( $this->options[GD_OPTIONS_GENERAL]['MoreInfoEmail'] )
            ? $this->options[GD_OPTIONS_GENERAL]['MoreInfoEmail'] : 'agent';
            
        $radio_html = '<label><input type="radio" name="%s" value="%s" %s>%s</label>';

        echo sprintf($radio_html,
            $name, 'agent', checked($value, 'agent', false), 'Agent');
        echo '<br>';
        echo sprintf($radio_html,
            $name, 'admin', checked($value, 'admin', false), 'Admin');
    }

    public function validate_general_options( $input ) {
        $output = $input;

        // Make sure this is a number
        $output['MaxDetailViews'] = intval( $input['MaxDetailViews'] );
        if ( !$output['MaxDetailViews'] ) {
            add_settings_error( GD_ADMIN_PAGE, 'invalid_view_count', 'You must enter a number for the max Listing Details page views', 'error' );
            return;
        }

        // If the boxes aren't checked they don't pass a value
        // so make sure we give them a value
        if ( !isset( $output['HideLoginLinks'] ) ) {
            $output['HideLoginLinks'] = '0';
        }

        add_settings_error( GD_ADMIN_PAGE, 'layout_and_extensions_updated', 'Layout: settings updated.', 'updated' );

        // Update agent info if all is good
        $_SESSION['gd']['agent']->max_detail_views = $output['MaxDetailViews'];
        return $output;
    }

    //////////////////////////
    // Our listings options //
    //////////////////////////

    public function render_listings_to_display_input() {
        $name = GD_OPTIONS_OUR_LISTINGS . '[ListingsToDisplay]';
        $value = isset( $this->options[GD_OPTIONS_OUR_LISTINGS]['ListingsToDisplay'] )
            ? $this->options[GD_OPTIONS_OUR_LISTINGS]['ListingsToDisplay']
            : 'agent'; // Defaults to agent listings

        echo '<label><input type="radio" name="' . $name . '" value="agent" ' . checked( $value, 'agent', false ) . '>Agent</label>';
        echo '<br>';
        echo '<label><input type="radio" name="' . $name . '" value="office" ' . checked( $value, 'office', false ) . '>Office</label>';
    }

    public function render_primary_source_input() {
        $sources = isset( $_SESSION['gd']['agent']->sources ) ? $_SESSION['gd']['agent']->sources : array( (object) array( 'id' => 0, 'name' => 'Demo' ) );

        $name = GD_OPTIONS_OUR_LISTINGS . '[Source]';
        $value = isset( $this->options[GD_OPTIONS_OUR_LISTINGS]['ListingsToDisplay'] )
            ? $this->options[GD_OPTIONS_OUR_LISTINGS]['ListingsToDisplay']
            : $sources[0]; // Default to first source

        echo '<select name="' . $name . '">';
        foreach ( $sources as $source ) {
            $id = $source->id;
            echo '<option value="' . $id . '" ' . checked( $value, $id, false ) . '>' . $source->name . '</option>';
        }
        echo '</select>';
    }

    public function render_our_listings_type_input() {
        $name = GD_OPTIONS_OUR_LISTINGS . '[Type]';
        $value = isset( $this->options[GD_OPTIONS_OUR_LISTINGS]['Type'] )
            ? $this->options[GD_OPTIONS_OUR_LISTINGS]['Type']
            : 'all';

        $this->render_listing_type_dropdown( $name, $value );
    }

    public function validate_our_listings_options( $input ) {
        $output  = $input;

        if ( isset( $_SESSION['gd']['agent']->sources ) ) {
            $sources = $_SESSION['gd']['agent']->sources;
            $source = $sources->{$input['Source']};

            if ( $input['ListingsToDisplay'] == 'agent' ) {
                $mlsCode = $source->mlsCode;
                if ( $mlsCode ) {
                    $output['Code'] = $mlsCode;
                } else {
                    add_settings_error( GD_ADMIN_PAGE, 'missing_agent_code', 'Our Listings: No agent MLS code was found for this source', 'error' );
                    return;
                }
            } else if ( $input['ListingsToDisplay'] == 'office' ) {
                $officeCode = $source->officeCode;
                if ( $officeCode ) {
                    $output['Code'] = $officeCode;
                } else {
                    add_settings_error( GD_ADMIN_PAGE, 'missing_office_code', 'Our Listings: No office MLS code was found for this source', 'error' );
                    return;
                }
            }
        }

        add_settings_error( GD_ADMIN_PAGE, 'our_listings_updated', 'Our Listings: settings updated.', 'updated' );

        return $output;
    }

    /////////////////////////////
    // Advanced search options //
    /////////////////////////////

    public function render_advanced_search_type_input() {
        $name = GD_OPTIONS_ADVANCED_SEARCH . '[DefaultType]';
        $value = isset( $this->options[GD_OPTIONS_ADVANCED_SEARCH]['DefaultType'] )
            ? $this->options[GD_OPTIONS_ADVANCED_SEARCH]['DefaultType']
            : 'all';

        $this->render_listing_type_dropdown( $name, $value );
    }

    public function render_custom_cities_input() {
        $options = $this->options[GD_OPTIONS_ADVANCED_SEARCH];
        $cities = API::call( 'GET', 'cities' );

        $toggle_name = GD_OPTIONS_ADVANCED_SEARCH . '[UseCustomCities]';
        $cities_name = GD_OPTIONS_ADVANCED_SEARCH . '[CustomCities]';
        $toggle_value = isset( $options['UseCustomCities'] )
            ? $options['UseCustomCities']
            : '0';
        $cities_values = isset( $options['CustomCities'] )
            ? $options['CustomCities']
            : array();

        echo '<label><input id="gd-use-custom-cities" type="checkbox" name="' . $toggle_name . '" value="1" ' . checked( $toggle_value, '1', false ) . '>Use custom cities</label>';
        echo '<ul id="gd-city-selection">';
        foreach ( $cities as $city ) {
            $name = "{$cities_name}[{$city->name}]";
            $checked = isset( $cities_values[$city->name] )
                ? checked( $cities_values[$city->name], '1', false )
                : '';

            echo '<li>';
            echo '<label><input type="checkbox" name="' . $name . '" ' . $checked . ' value="1">' . $city->name . '</label>';
            echo '</li>';
        }
        echo '</ul>'; ?>
        <script>
        var customCitiesToggle = document.getElementById('gd-use-custom-cities'),
            cityItems = document.getElementById('gd-city-selection');

        customCitiesToggle.onclick = function() {
            toggleCityItems(this.checked);
        }

        function toggleCityItems(checked) {
            cityItems.style.display = checked ? 'block' : 'none';
        }
        toggleCityItems(<?php echo $toggle_value == '1'; ?>);
        </script>
    <?php }

    public function render_map_search_start_inputs() {
        $options = $this->options[GD_OPTIONS_ADVANCED_SEARCH];
        $lat_name = GD_OPTIONS_ADVANCED_SEARCH . '[MapSearchStartLat]';
        $lat_value = $options['MapSearchStartLat'];
        $lon_name = GD_OPTIONS_ADVANCED_SEARCH . '[MapSearchStartLon]';
        $lon_value = $options['MapSearchStartLon'];
        $zoom_name = GD_OPTIONS_ADVANCED_SEARCH . '[MapSearchStartZoom]';
        $zoom_value = $options['MapSearchStartZoom'];
        ?>
        <fieldset>
            <input type="text" name="<?php echo $lat_name; ?>" value="<?php echo $lat_value; ?>" placeholder="Latitude">
            <input type="text" name="<?php echo $lon_name; ?>" value="<?php echo $lon_value; ?>" placeholder="Longitude">
            <br>
            <input type="number" name="<?php echo $zoom_name; ?>" value="<?php echo $zoom_value; ?>" placeholder="Zoom Level">
        </fieldset>
        <?php
    }

    public function validate_advanced_search_options( $input ) {
        $output = $input;

        if ( empty( $output['MapSearchStartLat'] ) ) {
            unset( $output['MapSearchStartLat'] );
        }
        if ( empty( $output['MapSearchStartLon'] ) ) {
            unset( $output['MapSearchStartLon'] );
        }
        if ( empty( $output['MapSearchStartZoom'] ) ) {
            unset( $output['MapSearchStartZoom'] );
        }

        add_settings_error( GD_ADMIN_PAGE, 'advanced_search_updated', 'Advanced Search: settings updated.', 'updated' );

        return $output;
    }

    /////////////////
    // Google Maps //
    /////////////////
    
    public function render_google_maps_api_key_input() {
        $name = GD_OPTIONS_GOOGLE_MAPS . '[ApiKey]';
        $value = isset( $this->options[GD_OPTIONS_GOOGLE_MAPS] ) ?
            $this->options[GD_OPTIONS_GOOGLE_MAPS]['ApiKey'] :
            '' ;
        ?>
        <input
            name="<?php echo $name; ?>"
            value="<?php echo $value; ?>"
            required>
        <br>
        <small>Please refer to the Google Maps documentation <a href="https://developers.google.com/maps/documentation/javascript/get-api-key#get-an-api-key" target="_blank">here</a> to learn how to create your API key.</small>
    <?php }
    public function validate_google_maps_options( $input ) {
        $output = array_map('sanitize_text_field', $input);
        return $output;
    }

    //////////////////
    // Social Media //
    //////////////////
    
    public function render_facebook_app_id_input() {
        $name = GD_OPTIONS_SOCIAL_MEDIA . '[AppId]';
        $value = isset( $this->options[GD_OPTIONS_SOCIAL_MEDIA] ) ?
            $this->options[GD_OPTIONS_SOCIAL_MEDIA]['AppId'] :
            '' ;
        ?>
        <input
            name="<?php echo $name; ?>"
            value="<?php echo $value; ?>"
            >
        <br>
        <small>Please refer to the Facebook App documentation <a href="https://developers.facebook.com/apps" target="_blank">here</a> to learn how to create a Facebook App.</small>
    <?php }

    public function validate_facebook_options( $input ) {
        $output = array_map('sanitize_text_field', $input);
        return $output;
    }

    //////////
    // URLs //
    //////////

    public function render_section_urls( $arg ) {
        echo '<strong>WARNGING: Change the below fields at your own risk.</strong>';
    }

    public function render_urls_listings_prefix_input() {
        $field = 'ListingsPrefix';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is what is prepended to all listing related pages.  For example ' . home_url() . "/$value/homes";
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function render_urls_account_prefix_input() {
        $field = 'AccountPrefix';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is what is prepended to all geodigs user account related pages.  For example ' . home_url() . "/$value";
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function render_urls_favorites_prefix_input() {
        $field = 'FavoritesPrefix';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is what is prepended to all favorite listings pages.  For example ' . home_url() . "/$value";
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function render_urls_proxy_api_input() {
        $field = 'ProxyApi';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is what is prepended to all proxy API calls made by the plugin\'s JavaScript.';
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function render_urls_document_store_input() {
        $field = 'DocumentStore';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is where the document store will be kept.'; 
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function render_urls_home_worth_input() {
        $field = 'HomeWorth';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value =  $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is where the home worth calculator will be located.';
        
        $this->render_text_input($name, $value, $desc);
    }
    public function render_urls_listing_alerts_input() {
        $field = 'ListingAlerts';
        $name = GD_OPTIONS_URLS . "[$field]";
        $value = $this->options[GD_OPTIONS_URLS][$field];
        $desc = 'This is where listing alerts can be viewed/modified.';
        
        $this->render_text_input($name, $value, $desc, true);
    }

    public function validate_url_options( $input ) {
        $output = array();

        if (
            empty( $input['ListingsPrefix'] ) ||
            empty( $input['AccountPrefix'] ) ||
            empty( $input['FavoritesPrefix'] ) ||
            empty( $input['ProxyApi'] ) ||
            empty( $input['DocumentStore'] ) ||
            empty( $input['HomeWorth'] ) ||
            empty( $input['ListingAlerts'] )
        ) {
            add_settings_error( GD_ADMIN_PAGE, 'urls_incomplete', 'URLs: All fields must have a value.', 'error' );
            return;
        }

        // Make sure each field ends with a "/".
        foreach ( $input as $key => $val ) {
            if ( substr( $val, -1) != '/') $val .= '/';

            $output[$key] = $val;
        } 

        add_settings_error( GD_ADMIN_PAGE, 'urls_updated', 'URLS: settings updated.', 'updated' );

        if ( $this->options[GD_OPTIONS_URLS] !== $output ) {
            $_SESSION['gd']['flush_rules'] = true;
        }

        return $output;
    }

    /**
     * Renders listing type dropdown
     * @param  string $name  Input/select name
     * @param  string $value Selected value
     */
    private function render_listing_type_dropdown( $name, $value ) {
        echo '<select name="' . $name . '">';
        echo '<option value="all">All</option>';
        foreach ( $this->listing_types as $type ) {
            $id = $type->id;
            echo '<option value="' . $id . '" ' . checked( $value, $id, false ) . '>' . $type->readable . '</option>';
        }
        echo '</select>';
    }

    /**
     * Renders a text box input with an optional description line.
     * @param string $name - Name of input field.
     * @param string $value - Value to store.
     * @param string $desc ('') - Optional description text.
     * @param bool   $required (false) - Mark the input as required.
     */
    private function render_text_input( $name, $value, $desc='', $required=false ) { ?> 
       <input
           name="<?php echo $name; ?>"
           value="<?php echo $value; ?>"
           <?php if ( $required ) echo 'required'; ?>
           >
       <br>
       <small><?php echo $desc; ?></small>
    <?php }
}

