<?php
namespace GeoDigs\Admin\Settings;

use GeoDigs\API as API;

/**
 * GeoDigs scripts and styles settings
 */
class ScriptsAndStyles extends Settings
{
	function __construct() {
		parent::__construct();

		$this->options = gd_get_option( GD_OPTIONS_SCRIPTS_AND_STYLES );
	}

	public function add_submenus() {
		add_submenu_page(
			GD_ADMIN_PAGE,
			'GeoDigs Scripts and Styles',
			'Scripts and Styles',
			'manage_options',
			GD_ADMIN_PAGE_SCRIPTS_AND_STYLES,
			array( &$this, 'render_page' )
		);
	}

	public function display_notices() {
		settings_errors( GD_ADMIN_PAGE_SCRIPTS_AND_STYLES );
	}

	public function render_page() { ?>
		<form method="post" action="options.php">
			<?php
			settings_fields( GD_OPTIONS_SCRIPTS_AND_STYLES );
			do_settings_sections( GD_ADMIN_PAGE_SCRIPTS_AND_STYLES );
			submit_button();
			?>
		</form>
	<?php }

	public function register_settings() {
		register_setting(
			GD_OPTIONS_SCRIPTS_AND_STYLES,
			GD_OPTIONS_SCRIPTS_AND_STYLES,
			array( &$this, 'validate' )
		);

		add_settings_section(
			'css',
			'Custom CSS',
			array( &$this, 'render_custom_css' ),
			GD_ADMIN_PAGE_SCRIPTS_AND_STYLES
		);
		add_settings_section(
			'scripts',
			'Dequeue Scripts',
			array( &$this, 'render_dequeued_scripts_section' ),
			GD_ADMIN_PAGE_SCRIPTS_AND_STYLES
		);
		add_settings_section(
			'styles',
			'Dequeue Styles',
			array( &$this, 'render_dequeued_styles_section' ),
			GD_ADMIN_PAGE_SCRIPTS_AND_STYLES
		);
	}


	////////////////////////////////////
	// METHODS SPECIFIC TO THIS CLASS //
	////////////////////////////////////

	public function render_custom_css() {
		$name = GD_OPTIONS_SCRIPTS_AND_STYLES . '[CustomCSS]';
		$value = $this->options['CustomCSS'];
		?>
		<h4>Enter custom styles to appear <em>only on GeoDigs pages.</em></h4>
		<textarea name="<?php echo $name; ?> " cols="30" rows="10" class="code form-control" style="max-width: 800px;"><?php echo $value; ?></textarea>
		<?php
	}

	public function render_dequeued_scripts_section() {
		global $wp_scripts;
		$name = GD_OPTIONS_SCRIPTS_AND_STYLES . '[DequeuedScripts]'; ?>

		<h4>Click a script to dequeue it.</h4>
		<div class="gd-admin-table__wrapper">
			<table class="gd-admin-table">
				<thead>
					<tr>
						<th>Dequeue</th>
						<th>Handle</th>
						<th>Source</th>
					</tr>
				</thead>
				<tbody>
					<?php foreach ( $wp_scripts->registered as $script ): ?>
						<?php
						$handle = $script->handle;
						$name = GD_OPTIONS_SCRIPTS_AND_STYLES . "[DequeuedScripts][{$handle}]";
						$id = 'script-' . $handle;
						$checked = isset( $this->options['DequeuedScripts'][$handle] )
							? checked( $this->options['DequeuedScripts'][$handle], '1', false )
							: '';
						?>
						<tr>
							<td><input type="checkbox" id="<?php echo $id; ?>" name="<?php echo $name; ?>" value="1" <?php echo $checked; ?>></td>
							<td><label for="<?php echo $id; ?>"><?php echo $handle; ?></label></td>
							<td><label for="<?php echo $id; ?>"><?php echo $script->src; ?></label></td>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		</div>
	<?php }
	
	public function render_dequeued_styles_section() {
		global $wp_styles;
		$name = GD_OPTIONS_SCRIPTS_AND_STYLES . '[DequeuedStyles]'; ?>

		<h4>Click a style to dequeue it.</h4>
		<div class="gd-admin-table__wrapper">
			<table class="gd-admin-table">
				<thead>
					<tr>
						<th>Dequeue</th>
						<th>Handle</th>
						<th>Source</th>
					</tr>
				</thead>
				<tbody>
					<?php foreach ( $wp_styles->registered as $style ): ?>
						<?php
						$handle = $style->handle;
						$name = GD_OPTIONS_SCRIPTS_AND_STYLES . "[DequeuedStyles][{$handle}]";
						$id = 'style-' . $handle;
						$checked = isset( $this->options['DequeuedStyles'][$handle] )
							? checked( $this->options['DequeuedStyles'][$handle], '1', false )
							: '';
						?>
						<tr>
							<td><input type="checkbox" id="<?php echo $id; ?>" name="<?php echo $name; ?>" value="1" <?php echo $checked; ?>></td>
							<td><label for="<?php echo $id; ?>"><?php echo $handle; ?></label></td>
							<td><label for="<?php echo $id; ?>"><?php echo $style->src; ?></label></td>
						</tr>
					<?php endforeach; ?>
				</tbody>
			</table>
		</div>
	<?php }

	public function validate( $input ) {
		$output = $input;

		add_settings_error( GD_ADMIN_PAGE_SCRIPTS_AND_STYLES, 'settings_saved', 'Settings saved.', 'updated' );

		return $output;
	}
}
