<?php
namespace GeoDigs\Admin\Settings;

use \GeoDigs\User as User;

/**
 * GeoDigs users settings
 */
class Users extends Settings
{
	public function add_submenus() {
		add_submenu_page(
			GD_ADMIN_PAGE,
			'GeoDigs Users',
			'Users',
			'manage_options',
			GD_ADMIN_PAGE_USERS,
			array( &$this, 'render_page' )
		);
	}
	public function display_notices() {}
	public function register_settings() {}

	public function render_page() {
		$first_name = isset( $_POST['firstName'] ) ? esc_attr( $_POST['firstName'] ) : '';
		$last_name = isset( $_POST['lastName'] ) ? esc_attr( $_POST['lastName'] ) : '';
		$phone = isset( $_POST['phone'] ) ? esc_attr( $_POST['phone'] ) : '';
		$email = isset( $_POST['email'] ) ? esc_attr( $_POST['email'] ) : '';
		$email_confirm = isset( $_POST['emailConfirm'] ) ? esc_attr( $_POST['emailConfirm'] ) : '';
		$address_street = isset( $_POST['addressStreet'] ) ? esc_attr( $_POST['addressStreet'] ) : '';
		$address_unit = isset( $_POST['addressUnit'] ) ? esc_attr( $_POST['addressUnit'] ) : '';
		$address_city = isset( $_POST['addressCity'] ) ? esc_attr( $_POST['addressCity'] ) : '';
		$address_zip = isset( $_POST['addressZip'] ) ? esc_attr( $_POST['addressZip'] ) : '';
		$address_state = isset( $_POST['addressState'] ) ? esc_attr( $_POST['addressState'] ) : '';

		if ( $first_name && $last_name && $phone
			&& $email && $email_confirm
		) {
			$_POST['type'] = 'geodigs';
			$_POST['agentCode'] = $_SESSION['gd']['agent']->code;

			// Generate random password
			$password = base_convert( microtime( false ), 10, 36 );
			$_POST['password'] = $password;
			$_POST['passwordConfirm'] = $password;

			// Signup user without notifying them on success or exiting on failure
			$errors = gd_process_signup(false, false);
			if ( count( $errors ) > 0 ) {
				foreach ( $errors as $error ) {
					$error_id = str_replace( ' ', '_', strtolower( $error ) );
					add_settings_error( GD_OPTIONS_USERS, $error_id, $error, 'error' );
				}
			} else {
				add_settings_error( GD_OPTIONS_USERS, 'gd_user_created', 'User created', 'updated' );

				// Notify user that their account was created
				$site_title = get_bloginfo();
				$message = array(
					'Your account at ' . $site_title . ' has been created using the following info:',
					'',
					'First Name: ' . $first_name,
					'Last Name: ' . $last_name,
					'Email: ' . $email,
					'Password: ' . $password,
				);
				if ( $address_street ) {
					$message[] = 'Address Street: ' . $address_street;
				}
				if ( $address_unit ) {
					$message[] = 'Address Unit: ' . $address_unit;
				}
				if ( $address_city ) {
					$message[] = 'Address City: ' . $address_city;
				}
				if ( $address_state ) {
					$message[] = 'Address State: ' . $address_state;
				}
				if ( $address_zip ) {
					$message[] = 'Address Zip: ' . $address_zip;
				}
				$message[] = '';
				$message[] = 'Go to ' . home_url() . ' to login!';
				$message = implode( "\r\n", $message );
				User::notify( $email, $site_title . ' Account Created', $message );
			}
		}

		/** Create table of users **/
		require_once GD_DIR_ADMIN_INCLUDES . '/users-table.php';

		// Create an instance of our package class...
		$calendar_table = new \GeoDigs_User_Table();
		// Fetch, prepare, sort, and filter our data...
		$calendar_table->prepare_items();

		settings_errors();
		?>

		<div class="wrap">
			<div class="row">
				<div class="col-md-4">
					<h2>Create User</h2>
					<form method="post" enctype="multipart/form-data">
						<table class="form-table">
							<tr>
								<th>First Name*</th>
								<td>
									<input type="text" class="form-control" name="firstName" required value="<?php echo $first_name; ?>">
								</td>
							</tr>
							<tr>
								<th>Last Name*</th>
								<td>
									<input type="text" class="form-control" name="lastName" required value="<?php echo $last_name; ?>">
								</td>
							</tr>
								<th>Phone*</th>
								<td>
									<input type="text" class="form-control" name="phone" required value="<?php echo $phone; ?>">
								</td>
							</tr>
							<tr>
								<th>Email*</th>
								<td>
									<input type="text" class="form-control" name="email" required value="<?php echo $email; ?>">
								</td>
							</tr>
							<tr>
								<th>Email Confirm*</th>
								<td>
									<input type="text" class="form-control" name="emailConfirm" required value="<?php echo $email_confirm; ?>">
								</td>
							</tr>
							<tr>
								<th>Address Street</th>
								<td>
									<input type="text" class="form-control" name="addressStreet" value="<?php echo $address_street; ?>">
								</td>
							</tr>
							<tr>
								<th>Address Unit</th>
								<td>
									<input type="text" class="form-control" name="addressUnit" value="<?php echo $address_unit; ?>">
								</td>
							</tr>
							<tr>
								<th>City</th>
								<td>
									<input type="text" class="form-control" name="addressCity" value="<?php echo $address_city; ?>">
								</td>
							</tr>
							<tr>
								<th>State</th>
								<td>
									<select name="addressState">
										<?php echo gd_state_list( $address_state ) ?>
									</select>
								</td>
							</tr>
							<tr>
								<th>Zip</th>
								<td>
									<input type="text" class="form-control" name="addressZip" value="<?php echo $address_zip; ?>">
								</td>
							</tr>
						</table>
						<?php submit_button( 'Create' ); ?>
					</form>
				</div>
				<div class="col-md-8">
					<?php $calendar_table->display(); ?>
				</div>
			</div>
		</div>
	<?php }
}
