<?php
namespace GeoDigs\Admin\Settings;

use GeoDigs\API as API;

/**
 * GeoDigs validation settings
 */
class Validation extends Settings
{
	function __construct() {
		parent::__construct();

		$this->options = gd_get_option( GD_OPTIONS_LOGIN );
	}

	public function add_submenus() {
		add_submenu_page(
			GD_ADMIN_PAGE,
			'GeoDigs Validation',
			'Validation',
			'manage_options',
			GD_ADMIN_PAGE_VALIDATION,
			array( &$this, 'render_page' )
		);
	}

	public function display_notices() {
		settings_errors( GD_ADMIN_PAGE_VALIDATION );
	}

	public function render_page() { ?>
		<form method="post" action="options.php">
			<?php
			settings_fields( GD_OPTIONS_LOGIN );
			do_settings_sections( GD_ADMIN_PAGE_VALIDATION );
			submit_button( 'Update' );
			?>
		</form>

		<?php if ( GD_LOGIN_STATUS !== 'success' ): ?>
			<div>
				<h1>Need a key?</h1>
				<p class="description">GeoDigs is a Denver/Boulder based product of New Media One Web Services that specializes in Real Estate website development and hosting services. As an original IDX vendor for MetroList and IRES, GeoDigs uses MLS and IDX to supply you with the technology needed to stay at the forefront of the Real Estate market.</p>

				<p>
					Check us out at <a href="http://geodigs.com/">GeoDigs.com</a>!
					<br>
					Then get in touch with us by <a href="mailto:support@newmediaone.net">email</a> or give us a call at 303-828-9882.
				</p>
				</h2>
			</div>
		<?php endif; ?>

	<?php }

	public function register_settings() {
		register_setting(
			GD_OPTIONS_LOGIN,
			GD_OPTIONS_LOGIN,
			array( &$this, 'validate' )
		);

		add_settings_section(
			GD_ADMIN_SECTION_VALIDATION,
			'Validation',
			array( &$this, 'render_status' ),
			GD_ADMIN_PAGE_VALIDATION
		);

		add_settings_field(
			'agent_code',
			'Agent Code',
			array( &$this, 'render_agent_code_input' ),
			GD_ADMIN_PAGE_VALIDATION,
			GD_ADMIN_SECTION_VALIDATION
		);

		add_settings_field(
			'agent_key',
			'API Key',
			array( &$this, 'render_api_key_input' ),
			GD_ADMIN_PAGE_VALIDATION,
			GD_ADMIN_SECTION_VALIDATION
		);
	}


	////////////////////////////////////
	// METHODS SPECIFIC TO THIS CLASS //
	////////////////////////////////////

	public function render_status() {
		switch ( GD_LOGIN_STATUS ) {
			case 'success':
				echo '<div class="notice notice-success"><p>API key is valid</p></div>';
				break;

			case 'invalid':
				echo '<div class="notice notice-error"><p>API key is invalid</p></div>';
				break;

			case 'demo':
				echo '<div class="notice notice-warning"><p>Demo API key is in use</p></div>';
				break;
		}
	}
	public function render_agent_code_input() {
		$name = GD_OPTIONS_LOGIN . '[AgentCode]';
		$value = $this->options['AgentCode'];

		echo '<input type="text" id="geodigs-agent-code" name="' . $name . '" value="' . $value . '" maxlength="5">';
	}
	public function render_api_key_input() {
		$name = GD_OPTIONS_LOGIN . '[APIKey]';
		$value = $this->options['APIKey'];

		echo '<input type="text" id="geodigs-api-key" name="' . $name . '" value="' . $value . '" maxlength="40">';
	}

	public function validate( $input ) {
		$output = $input;

		if ( $input['AgentCode'] && $input['APIKey'] ) {
			// Test the new API key to validate the agent code
			API::set_key( $input['APIKey'] );
			$agent_response = API::call( 'GET', 'agents/' . $input['AgentCode'] );

			$error = isset( $agent_response->error )
				? $agent_response->message
				: false;

			if ( $error ) {
				$output['Status'] = 'invalid';
				add_settings_error(
					GD_ADMIN_PAGE_VALIDATION,
					'invalid_login',
					$error
				);
			} elseif ( $agent_response->name ) {
				$output['Status'] = 'success';
				if ( false == get_settings_errors( GD_ADMIN_PAGE_VALIDATION ) ) {
					add_settings_error( GD_ADMIN_PAGE_VALIDATION, 'successful_login', 'Welcome to GeoDigs!', 'updated' );
				}
			}

		} else {
			$output['AgentCode'] = API::DEMO_AGENT_CODE;
			$output['APIKey'] = API::DEMO_KEY;
		}

		return $output;
	}
}
