var siteUrl = wp_params.home_url + '/',
	proxyApiUrl = siteUrl + wp_params.proxy_api_url;

(function($) {
	$(document).ready(function() {

		// Modal toggles
		$('.gd-mortgage-calc-modal-toggle').click(function(e) {
			if ($('#gd-mortgage-calc-modal')) {
				e.preventDefault();
				$('#gd-mortgage-calc-modal').modal('toggle');
			}
		});
		$('.gd-quick-search-modal-toggle').click(function(e) {
			if ($('#gd-quick-search-modal')) {
				e.preventDefault();
				$('#gd-quick-search-modal').modal('toggle');
			}
		});

		// Toggle favorite button
		$('.gd-favorite-toggle').click(function(e) {
			var url        = wp_params.home_url + '/favorites/',
				listing_id   = $(this).attr('data-listing-id'),
				toggle_class = 'gd-favorite-toggle-on',
				toggle       = $(this);

			if (toggle.hasClass(toggle_class)) {
				url += 'delete/?listing_id=' + listing_id;
			}
			else {
				url += 'add/?listing_id=' + listing_id;
			}

			$.ajax({
				url: url,
				success: function(data, textStatus, jqXHR) {
					toggle.toggleClass(toggle_class);
				}
			});
		});

		// Back button  (for back to search results typically)
		$('#gd-back').click(function(e) {
			e.preventDefault();
			window.history.back();
		});

		// Search Results sort by
		$('.gd-sorting-control select').change(function(e) {
			var url              = window.location.href,
				val              = $(this).val(),
				sort             = val.split('::'),
				orderBy          = sort[0],
				orderByDirection = sort[1];

			url = updateQueryStringParameter(url, 'orderBy', orderBy);
			url = updateQueryStringParameter(url, 'orderByDirection', orderByDirection);
			window.location.assign(url);
		});
	});

	// Numbers only
	$('.number-input').keyup(function() {
		this.value = this.value.replace(/[^0-9\.]/g,'');
	});

	// Toggle accordian
	$('.gd-accordian .gd-accordian-title').click(function(e) {
		$(this).parent().toggleClass('gd-accordian-show');
	});

	// Ajax loading for lists
	$('.ajax-list').each(function() {
		var list = $(this);
		var url = list.attr('data-url');

		// Figure out if a relative or absolute file path was provided
		if (url.indexOf(siteUrl) == -1) {
			url = siteUrl + list.attr('data-url');
		}

		var items = $.getJSON(url, function(data) {
			var options = [],
				selected = false;

			$.each(data, function(key, val) {
				if (val.readable !== '') {

					var option = $('<option></option>')
						.text(val.readable)
						.val(val.id);

					if (list.attr('data-selected') == val.id) {
						option.attr('selected', 'selected');
						selected = true;
					} else if (list.attr('data-default') == val.id && !selected) {
						option.attr('selected', 'selected');
					}

					list.append(option);
				}

			});
			list.trigger('ajax-list:updated');
		})
		.fail(function( jqxhr, textStatus, error ) {
			var err = textStatus + ", " + error;
			console.log( "Request Failed: " + err );
		});
	});

	function callApi( method, route, data ) {
		$.ajax({
			url: proxyApiUrl + route,
			type: method,
			dataType: 'json',
			contentType: 'application/json',
			processData: false,
			data: data,
			success: function ( data ) {
			  return data;
			},
			error: function(){
			  console.log( 'Could not connect to proxy API' );
			}
		});
	}
	// Export to global scope
	window.callApi = callApi;

})(jQuery);

function updateQueryStringParameter(uri, key, value) {
	var re = new RegExp("([?&])" + key + "=.*?(&|$)", "i");
	var separator = uri.indexOf('?') !== -1 ? "&" : "?";

	if (uri.match(re)) {
		return uri.replace(re, '$1' + key + "=" + value + '$2');
	}
	else {
		return uri + separator + key + "=" + value;
	}
}

// For easy string formatting
// First, checks if it isn't implemented yet.
if (!String.prototype.format) {
	String.prototype.format = function() {
		var args = arguments;
		return this.replace(/{(\d+)}/g, function(match, number) {
			return typeof args[number] != 'undefined' ? args[number] : match;
		});
	};
}
