<?php
namespace GeoDigs;

class Calendars {
	const TABLE = 'gd_calendars';

	static function init() {
		global $wpdb;

		/* START Create tables */

		$create_table_query = 'CREATE TABLE IF NOT EXISTS ' . self::TABLE . " (
  `id` int( 11 ) NOT NULL auto_increment,
  `userId` int( 11 ) default NULL,
  `name` varchar( 100 ) NOT NULL default '',
  `link` TEXT default NULL,
  `modDate` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  ( `id` ),
  KEY `userId` ( `userId` )
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;";
		$wpdb->query( $create_table_query );

		/* END Create tables */
	}

	static function get_all() {
		global $wpdb;

		$query = 'SELECT id, userId, name, link, modDate FROM ' . self::TABLE;
		return $wpdb->get_results( $query );
	}

	static function get( $id ) {
		global $wpdb;

		$table = self::TABLE;
		$query = $wpdb->prepare( "SELECT id, userId, name, link, modDate
			FROM $table
			WHERE id = %s", $id );

		return $wpdb->get_row( $query );
	}

	static function get_for_user( $userId ) {
		global $wpdb;

		$table = self::TABLE;
		$query = $wpdb->prepare( "SELECT id, userId, name, link, modDate
			FROM $table
			WHERE userId = %s", $userId );

		return $wpdb->get_results( $query );
	}

	static function add( $userId, $name, $link ) {
		global $wpdb;

		$wpdb->insert(
			self::TABLE,
			array(
				'userId' => $userId,
				'name'   => $name,
				'link'   => $link,
			)
		);
	}

	static function update( $id, $userId, $name, $link ) {
		global $wpdb;

		$wpdb->update(
			self::TABLE,
			array(
				'userId' => $userId,
				'name'   => $name,
				'link'   => $link,
			),
			array(
				'id' => $id
			)
		);
	}

	static function delete( $id ) {
		global $wpdb;

		$wpdb->delete( self::TABLE, array( 'id' => $id ) );
	}
}
