<?php

namespace GeoDigs;

/**
* GeoDigs Custom Searches
*/
class CustomSearches
{
	const ROUTE = 'searches/custom';

	/**
     * Add custom search
     * @param  array $data   Custom search data
	 * @param  bool  $notify Notify user of status
	 * @return bool          Group added
	 */
	static function add( $data, $notify = true ) {
        API::enable_debug();
		$added = API::call( 'POST', self::ROUTE, $data );
        $error = isset( $added->error ) ? $added->error : false;

		if ( $notify ) {
			if ( $error ) {
				add_settings_error( GD_OPTIONS_CUSTOM_SEARCHES,
					'add_error',
					'Could not add custom search: ' . $added->message,
					'error' );
			} else {
				add_settings_error( GD_OPTIONS_CUSTOM_SEARCHES, 'add_success', 'Custom search added', 'updated' );
			}
        }

        return $added;
	}

	/**
	 * Get custom search
	 * @param  integer $id ID of custom search
	 * @return object      Custom search data
	 */
	static function get( $id ) {
		return API::call( 'GET', self::ROUTE . "/{$id}" );
	}

	/**
	 * Delete custom search
	 * @param  integer $id     ID of custom search
	 * @param  bool    $notify Notify user of status
	 * @return bool            Deleted custom search
	 */
	static function delete( $id, $notify = true ) {
		$deleted = API::call( 'DELETE', self::ROUTE . "/{$id}" );
		$error = isset( $deleted->error ) ? $deleted->error : false;

		if ( $notify ) {
			if ( $error ) {
				add_settings_error( GD_OPTIONS_CUSTOM_SEARCHES,
					'delete_error',
					'Could not delete custom search: ' . $deleted->message,
					'error' );
			} else {
				add_settings_error( GD_OPTIONS_CUSTOM_SEARCHES, 'delete_success', 'Custom search deleted', 'updated' );
			}

			return !$error;
		} else {
			return $deleted;
		}
	}

	/**
	 * Update a custom search
	 * @param  integer $id     Custom search ID
	 * @param  bool    $notify Notify user of status
	 * @return bool            Custom search updated
	 */
	static function update( $id, $notify = true ) {
		$data = gd_convert_post_to_custom_search_data();
		$updated = API::call( 'PUT', self::ROUTE . "/{$id}", $data );

		if ( $notify ) {
			if ( isset( $updated->error ) ) {
				add_settings_error(
					GD_OPTIONS_CUSTOM_SEARCHES,
					'update_error',
					'Could not update custom search: ' . $updated->message,
					'error'
				);
			} else {
				add_settings_error(
					GD_OPTIONS_CUSTOM_SEARCHES,
					'update_success',
					'Custom search updated',
					'updated'
				);
			}
		}
        return $updated;
	}
}
