<?php
namespace GeoDigs;

class DocumentStore {
	static $db;
	static $path;
	static $files_table;


	static function init() {
		// This makes calling the WP database object easier
		global $wpdb;
		self::$db = $wpdb;

		// Set the path and create the directory if it doesn't exist
		self::$path = $_SERVER['DOCUMENT_ROOT'] . '/geodigs/document-store/';
		if ( !file_exists( self::$path ) ) {
			mkdir( self::$path, 0777, true );
		}

/* 		START Create tables */

		self::$files_table = 'gd_ds_files';
		$create_files_table_query = "CREATE TABLE IF NOT EXISTS `" . self::$files_table . "` (
  `id` int( 11 ) NOT NULL auto_increment,
  `userId` int( 11 ) default NULL,
  `name` varchar( 100 ) NOT NULL default '',
  `keywords` varchar( 255 ) default NULL,
  `extension` varchar( 10 ) default NULL,
  `description` varchar( 255 ) default NULL,
  `fileName` varchar( 100 ) NOT NULL default '',
  `sort` bigint( 20 ) NOT NULL default '99999',
  `size` bigint( 20 ) default NULL,
  `modDate` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  `owner` varchar( 100 ) default NULL,
  `active` tinyint( 4 ) NOT NULL default '1',
  PRIMARY KEY  ( `id` ),
  KEY `name` ( `name` ),
  KEY `fileName` ( `fileName` ),
  FULLTEXT KEY `keywords` ( `keywords`,`description` )
) ENGINE=MyISAM  DEFAULT CHARSET=latin1;";
		self::$db->query( $create_files_table_query );

/* 		END Create tables */
	}

	static function get_users() {
		return API::call( 'GET', 'users' );
	}

	static function notify_user( $name, $user_id ) {
		$user = API::call( 'GET', 'users/' . $user_id );

		$to			= $user->email;
		$subject	= get_bloginfo( 'name' ) . ': A File Was Added to Your Document Store!';
		$headers	= 'From: ' . get_bloginfo( 'admin_email' ) . "\r\n" . 'Reply-To: ' . get_bloginfo( 'admin_email' ) . "\r\n" . 'X-Mailer: PHP/' . phpversion();
		// Get email contents
		ob_start();
		include_once GD_DIR_EMAILS . 'new-file-added-to-document-store.php';
		$message = ob_get_contents();
		ob_end_clean();
		// Send it
		mail( $to, $subject, $message, $headers );
	}

	static function download_file( $id ) {
		if ( isset( $id ) ) {
			header( 'Content-Type: application/octet-stream' );
			header( 'Content-Disposition: attachment; filename="' . self::get_file_name( $id, 'WITH_EXTENSION' ) . '"' );
			header( 'Content-Length: ' . self::get_file_size( $id ) );

			ob_clean();
			flush();
			readfile( self::get_file_path( $id ) );
			exit;
		} else {
			echo 'No document ID specified.';
			exit;
		}
	}

	static function get_files( $user_id = null ) {
		$files_table = self::$files_table;
		$query = "SELECT * FROM {$files_table}";
		if ( isset( $user_id ) ) {
			$query .= " WHERE `userId` = {$user_id} ORDER BY `name`";
		}

		$files = self::$db->get_results( $query );
		if ( is_array( $files ) ) {
			return $files;
		} else {
			self::$db->print_error();
			return false;
		}
	}

	static function get_file( $id ) {
		$files_table = self::$files_table;
		$query = self::$db->prepare( "SELECT * FROM {$files_table} WHERE id=%s", $id );
		return self::$db->get_row( $query );
	}

	static function add_file( $name, $description, $user_id, $active = 'active' ) {
		// If we can successfully upload the file add it to the DB
		$file_path_info = pathinfo( $_FILES['file']['name'] );
		self::$db->insert(
			self::$files_table,
			array(
				'userId'      => $user_id,
				'name'        => stripslashes( $name ),
				'extension'   => $file_path_info['extension'],
				'description' => stripslashes( $description ),
				'fileName'    => $file_path_info['filename'],
				'size'        => $_FILES['file']['size'],
				'owner'       => $_SESSION['gd']['agent']->name->full,
				'active'      => ( $active == 'active' ),
			)
		);

		if ( self::upload_file( self::$db->insert_id ) ) {
			echo 'Document uploaded successfully';
		} else {
			self::$db->delete( self::$files_table, array( 'id' => $id ) );
			echo 'Could not upload file';
		}
	}

	static function update_file( $id, $name, $description, $user_id, $active = 'active' ) {
		// Get file path
		$file = self::get_file_path( $id );

		// Delete the file
		if ( unlink( $file ) ) {
			$file_path_info = pathinfo( $_FILES['file']['name'] );
			self::$db->update(
				self::$files_table,
				array(
					'userId'      => $user_id,
					'name'        => stripslashes( $name ),
					'extension'   => $file_path_info['extension'],
					'description' => stripslashes( $description ),
					'fileName'    => $file_path_info['filename'],
					'size'        => $_FILES['file']['size'],
					'owner'       => $_SESSION['gd']['agent']->name->full,
					'active'      => ( $active == 'active' ),
				),
				array(
					'id' => $id,
				)
			);

			if ( self::upload_file( $id ) ) {
				echo 'Document updated successfully';
			}
		}
	}

	static function delete_file( $id ) {
		// Get file path
		$file = self::get_file_path( $id );

		// Delete the file
		// If the file doesn't exist but it exists in the database delete it
		if ( unlink( $file ) || !file_exists( $file ) ) {
			// Delete DB entry
			self::$db->delete( self::$files_table, array( 'id' => $id ) );
			echo 'File deleted successfully';
		}
		else {
			echo 'Could not delete file';
		}
	}

	private static function get_file_path( $id ) {
		return self::$path . $id . '.' . self::get_file_extension( $id );
	}

	private static function get_file_name( $id, $flag ) {
		switch ( $flag ) {
			// returns name.type
			case 'WITH_EXTENSION':
				$query = self::$db->prepare( "SELECT
					CONCAT( `fileName`, '.', `extension` ) AS `fileName`
					FROM `" . self::$files_table . "`
					WHERE `id` = %d", $id );
				return self::$db->get_var( $query );
				break;
			// returns name
			case 'NO_EXTENSION':
				$query = self::$db->prepare( "SELECT `fileName` FROM `" . self::$files_table . "` WHERE `id` = %d", $id );
				return self::$db->get_var( $query );
			default:
		}
	}

	private static function get_file_extension( $id ) {
		$query = self::$db->prepare( 'SELECT `extension`
			FROM `' . self::$files_table . '`
			WHERE `id` = %s', $id );
		return self::$db->get_var( $query );
	}

	private static function get_file_size( $id ) {
		$query = self::$db->prepare( "SELECT size FROM `" . self::$files_table . "` WHERE id = %s", $id );
		return self::$db->get_var( $query );
	}

	private static function upload_file( $name ) {
		try {
			// Undefined | Multiple Files | $_FILES Corruption Attack
			// If this request falls under any of them, treat it invalid.
			if (
				!isset( $_FILES['file']['error'] ) ||
				is_array( $_FILES['file']['error'] )
			) {
				throw new RuntimeException( 'Invalid parameters.' );
			}

			// Check $_FILES['file']['error'] value.
			switch ( $_FILES['file']['error'] ) {
				case UPLOAD_ERR_OK:
					break;
				case UPLOAD_ERR_NO_FILE:
					throw new RuntimeException( 'No file sent.' );
				case UPLOAD_ERR_INI_SIZE:
				case UPLOAD_ERR_FORM_SIZE:
					throw new RuntimeException( 'Exceeded filesize limit.' );
				default:
					throw new RuntimeException( 'Unknown errors.' );
			}

			// You should also check filesize here.
			// if ( $_FILES['file']['size'] > 1000000 ) {
			// 	throw new RuntimeException( 'Exceeded filesize limit.' );
			// }

			// Get the id of the last file uploaded and add 1 to it to get the new file name
			$file_path_info = pathinfo( $_FILES['file']['name'] );
			$file_name = $name . '.' . $file_path_info['extension'];

			if ( !move_uploaded_file(
				$_FILES['file']['tmp_name'],
				self::$path . $file_name
			) ) {
				throw new RuntimeException( 'Failed to move uploaded file.' );
			}

			return true;

		} catch ( RuntimeException $e ) {

			echo $e->getMessage();
			return false;
		}
	}
}
DocumentStore::init();
