<?php
/**
 * This class handles the GeoDigs template system
 */
namespace GeoDigs;

class Template {
	// Variables
	private static $local_path;
	private static $root_path; // deprecated
	private static $theme_path;
	private static $templates;

	/**
	 * Initialize the GeoDigs templating system
	 */
	static function init()
	{
		// Set the path and create the directory if it doesn't exist
		self::$root_path = $_SERVER['DOCUMENT_ROOT'] . '/geodigs/templates/';
		if ( !file_exists( self::$root_path ) ) {
			mkdir( self::$root_path, 0777, true );
		}

		// Set the local path
		self::$local_path = dirname( __FILE__ ) . '/../templates/';

		// Set the theme path
		self::$theme_path = get_template_directory() . '-child/geodigs/templates/';

		// Get our templates
		self::$templates = array();
		// self::import();
	}

	/**
	 * Get all files in the GeoDigs template directory
	 */
	static function import()
	{
		// Setup recursive iterators
		$recursiveDirectoryIterator = new \RecursiveDirectoryIterator( self::$root_path, \RecursiveDirectoryIterator::SKIP_DOTS );
		$recursiveIteratorIterator = new \RecursiveIteratorIterator( $recursiveDirectoryIterator );

		// Get all the files
		foreach( $recursiveIteratorIterator as $file ) {
			// If they are php or html files add them to our template list
			$extention = pathinfo( $file, PATHINFO_EXTENSION );
			if ( $extention == 'php' || $extention == 'html' ) {
				array_push( self::$templates, $file );
			}
		}
	}

	/**
	 * Gets and outputs the template
	 * @param  string $template Template file to use
	 * @param  array $vars      php variables to pass to the template
	 * @param  bool $output     Output the results or return them
	 */
	static function load( $template, $vars = array(), $output = true )
	{
		// First we check the theme path,
		// then the root path,
		// then the local path (default)
		$file = self::$theme_path . $template;
		if ( !file_exists( $file ) ) {

			$file = self::$root_path . $template;
			if ( !file_exists( $file ) ) {

				$file = self::$local_path . $template;
				if ( !file_exists( $file ) ) {

					echo 'Could not find template file ' . $file;
					return false;
				}
			}
		}

		// Extract variables
		extract( $vars );

		// Begin output
		ob_start();

		echo "<!-- BEGIN {$file} -->";
		include $file;
		echo "<!-- END {$file} -->";

		// If we aren't outputting the buffer contents return the contents
		if ( $output ) {
			ob_end_flush();
			return true;
		} else {
			return ob_get_clean();
		}
	}
}
Template::init();
