<?php
/**
 * Helper function to render a dropdown.
 *
 * @param  string $name     Form input name.
 * @param  array  $options  Array of options.
 * @param  string $selected Initial selected value.
 */
function gd_render_dropdown( $name, $options, $selected ) {
	echo '<select name="' . $name . '" class="form-control">';
	echo '<option value="">Any</option>';
	foreach ( $options as $option ) {
		echo sprintf(
			'<option %s value="%s">%s</option>',
			selected( $selected, $option->id, false ),
			$option->id, $option->readable
		);
	}
	echo '</select>';
}

/**
 * Creates the HTML for a listing detail table.  This could be done better but
 * for backwards compatability sake it isn't.
 *
 * @param  array   $array          Key value pairs.
 * @param  integer $col            Number of columns.
 * @param  boolean $separate_cells Seperate key value pairs into separate cells.
 * @return string                  Table HTML
 */
function gd_create_table_str( $array, $col = 2, $separate_cells = false ) {
	$count     = 0;
	$table_str = '<table>';

	foreach ( $array as $key => $value ) {
		if ( $value ) {
			$title = esc_html( $key );
			$val   = esc_html( $value );

			if ( $separate_cells ) {
				$table_str .= '<tr>';
				$table_str .= "<td><strong>{$title}:</strong></td>";
				$table_str .= "<td>{$val}</td>";
				$table_str .= '</tr>';
			} else {
				if ( $col > 1 ) {
					// 2 items per row
					if ( 0 === $count % $col ) {
						// Close the previous row if this isn't the first row.
						if ( 0 !== $count ) {
							$table_str .= '</tr>';
						}
						$table_str .= '<tr>';
					}

					$table_str .= "<td><strong>{$title}:</strong> {$val}</td>";

					// If this was our last one close the row.
					if ( count( $array ) - 1 === $count ) {
						$table_str .= '</tr>';
					}
				} else {
					$table_str .= "<tr><td><strong>{$title}:</strong> {$val}</td></tr>";
				}

				$count++;
			}
		}
	}

	$table_str .= '</table>';
	return $table_str;
}

/**
 * Renders the options for a state select element.
 *
 * @param  string $current Initial selected option.
 */
function gd_state_list( $current ) {
	$states = array(
		array( 'value' => '', 'label' => 'State' ),
		array( 'value' => 'AL', 'label' => 'Alabama' ),
		array( 'value' => 'AK', 'label' => 'Alaska' ),
		array( 'value' => 'AZ', 'label' => 'Arizona' ),
		array( 'value' => 'AR', 'label' => 'Arkansas' ),
		array( 'value' => 'CA', 'label' => 'California' ),
		array( 'value' => 'CO', 'label' => 'Colorado' ),
		array( 'value' => 'CT', 'label' => 'Connecticut' ),
		array( 'value' => 'DE', 'label' => 'Delaware' ),
		array( 'value' => 'DC', 'label' => 'District Of Columbia' ),
		array( 'value' => 'FL', 'label' => 'Florida' ),
		array( 'value' => 'GA', 'label' => 'Georgia' ),
		array( 'value' => 'HI', 'label' => 'Hawaii' ),
		array( 'value' => 'ID', 'label' => 'Idaho' ),
		array( 'value' => 'IL', 'label' => 'Illinois' ),
		array( 'value' => 'IN', 'label' => 'Indiana' ),
		array( 'value' => 'IA', 'label' => 'Iowa' ),
		array( 'value' => 'KS', 'label' => 'Kansas' ),
		array( 'value' => 'KY', 'label' => 'Kentucky' ),
		array( 'value' => 'LA', 'label' => 'Louisiana' ),
		array( 'value' => 'ME', 'label' => 'Maine' ),
		array( 'value' => 'MD', 'label' => 'Maryland' ),
		array( 'value' => 'MA', 'label' => 'Massachusetts' ),
		array( 'value' => 'MI', 'label' => 'Michigan' ),
		array( 'value' => 'MN', 'label' => 'Minnesota' ),
		array( 'value' => 'MS', 'label' => 'Mississippi' ),
		array( 'value' => 'MO', 'label' => 'Missouri' ),
		array( 'value' => 'MT', 'label' => 'Montana' ),
		array( 'value' => 'NE', 'label' => 'Nebraska' ),
		array( 'value' => 'NV', 'label' => 'Nevada' ),
		array( 'value' => 'NH', 'label' => 'New Hampshire' ),
		array( 'value' => 'NJ', 'label' => 'New Jersey' ),
		array( 'value' => 'NM', 'label' => 'New Mexico' ),
		array( 'value' => 'NY', 'label' => 'New York' ),
		array( 'value' => 'NC', 'label' => 'North Carolina' ),
		array( 'value' => 'ND', 'label' => 'North Dakota' ),
		array( 'value' => 'OH', 'label' => 'Ohio' ),
		array( 'value' => 'OK', 'label' => 'Oklahoma' ),
		array( 'value' => 'OR', 'label' => 'Oregon' ),
		array( 'value' => 'PA', 'label' => 'Pennsylvania' ),
		array( 'value' => 'RI', 'label' => 'Rhode Island' ),
		array( 'value' => 'SC', 'label' => 'South Carolina' ),
		array( 'value' => 'SD', 'label' => 'South Dakota' ),
		array( 'value' => 'TN', 'label' => 'Tennessee' ),
		array( 'value' => 'TX', 'label' => 'Texas' ),
		array( 'value' => 'UT', 'label' => 'Utah' ),
		array( 'value' => 'VT', 'label' => 'Vermont' ),
		array( 'value' => 'VA', 'label' => 'Virginia' ),
		array( 'value' => 'WA', 'label' => 'Washington' ),
		array( 'value' => 'WV', 'label' => 'West Virginia' ),
		array( 'value' => 'WI', 'label' => 'Wisconsin' ),
		array( 'value' => 'WY', 'label' => 'Wyoming' ),
	);

	foreach ( $states as $state ) {
		echo '<option value="' . $state['value'] . '" ' . selected( $current, $state['value'] ) . '>' . $state['label']  . '</option>';
	}
}

function gd_convert_post_to_custom_search_data() {
	$blacklist = array(
		'push',
		'text',
		'email',
		'freq',
		'search_name',
		'name',
		'sort',
		'displayCount',
		'layout',
		'showMap',
		'fill',
	);
	$data = $_POST;
	$params = array();

	foreach ( $data as $key => $value ) {
		if ( ! in_array( $key, $blacklist, true ) ) {
			if ( '' !== $value ) {
				if ( 'polygon' === $key ) {
					// Replace the commas because the API recognizes commas as metacharacters.
					$value = str_replace( ',', '|', $value );
				}

				$params[ $key ] = $value;
			}

			unset( $data[ $key ] );
		}
	}

	$data['params'] = $params;

	return $data;
}

function gd_enable_debug() {
	ini_set( 'display_errors', 'On' );
	error_reporting( E_ALL );
}

function gd_create_listing_url( $listing, $action='return' ) {
    $url = home_url( sprintf( '/%s?listing_id=%s&address=%s',
        GD_URL_MORE_INFO, $listing->id, urlencode( $listing->address->readable ) ) );

	if ( strtolower( $action ) == 'echo' ) {
		echo $url;
	} else {
		return $url;
	}
}

function gd_create_listing_image_url( $listing, $pos, $size='large' ) {
	switch ( $size ) {
		case 'large':
			$width = 1080;
			break;
		case 'fullscreen':
			$width = 1900;
	}

	$str = 'http://images.geodigs.com/%d/image.jpg?id=%s&w=%d&pos=%d';
	return sprintf(
		$str,
		$listing->source->id,
		$listing->mlsNumber,
		$width,
		$pos
	);
}
