<?php
/**
 * GeoDigs Navigation
 */

use \GeoDigs\User as User;

/**
 * Creates/updates the navigation menu.
 */
function gd_create_nav_menu() {
	// Check if the menu exists
    $menu_slug = 'GeoDigs';
	$menu = wp_get_nav_menu_object( $menu_slug );

    $our_listings_id = 0;
    $our_listings_title = 'Our Listings';
    $adv_search_id = 0;
    $adv_search_title = 'Advanced Search';
    $home_worth_id = 0;
    $home_worth_title = "What's my Home Worth";

    if ( $menu ) {
        $menu_id = $menu->term_id;
        $menu_items = wp_get_nav_menu_items( $menu_slug );

        foreach ( $menu_items as $item ) {
            if ( $item->title == $our_listings_title ) {
                $our_listings_id = $item->ID;
            } else if ( $item->title == $adv_search_title ) {
                $adv_search_id = $item->ID;
            } else if ( $item->title == $home_worth_title ) {
                $home_worth_id = $item->ID;
            }
        }
    } else {
        $menu_id = wp_create_nav_menu( $menu_slug );
    }

    if ( !$menu || ( $menu && $our_listings_id != 0 ) ) {
        wp_update_nav_menu_item( $menu_id, $our_listings_id, array(
	    	'menu-item-title'  =>  __( $our_listings_title ),
	    	'menu-item-url'    => home_url( '/' . GD_URL_OUR_LISTINGS ),
	    	'menu-item-status' => 'publish'
        ) );
    }

    if ( !$menu || ( $menu && $adv_search_id != 0 ) ) {
    	wp_update_nav_menu_item( $menu_id, $adv_search_id, array(
    		'menu-item-title'  =>  __( $adv_search_title ),
    		'menu-item-url'    => home_url( '/' . GD_URL_ADV_SEARCH ),
    		'menu-item-status' => 'publish'
    	) );
    }

    if ( !$menu || ( $menu && $home_worth_id != 0 ) ) {
    	wp_update_nav_menu_item( $menu_id, $home_worth_id, array(
    		'menu-item-title'  =>  __( $home_worth_title ),
    		'menu-item-url'    => home_url( '/' . GD_URL_HOME_WORTH ),
    		'menu-item-status' => 'publish'
        ) );
    }
}
add_action( 'wp_head', 'gd_create_nav_menu' );

// Add user account links
function gd_add_nav_menu_items( $items, $args ) {
	$general_settings = gd_get_option( GD_OPTIONS_GENERAL );
	if ( !isset( $general_settings['HideLoginLinks'] )
		|| $general_settings['HideLoginLinks'] !== '1'
	) {
		// If the user is logged in add a link to their account
		if ( User::is_logged_in() ) {
			$items .= '<li id="gd-my-account-link" class="menu-item menu-item-type-custom menu-item-object-custom menu-item-has-children"><a href="' . home_url( GD_URL_ACCOUNT, 'relative' ) . '">My Account</a>';
				$items .= '<ul class="sub-menu">';
					$items .= '<li><a id="gd-my-account-home-link" class="menu-item menu-item-type-custom menu-item-object-custom" href="' . home_url( GD_URL_ACCOUNT, 'relative' ) . '">Home</a></li>';
					$items .= '<li><a id="gd-my-account-favorites-link" class="menu-item menu-item-type-custom menu-item-object-custom" href="' . home_url( GD_URL_FAVORITES, 'relative' ) . '">Favorites</a></li>';
					$items .= '<li><a id="gd-my-account-alerts-link" class="menu-item menu-item-type-custom menu-item-object-custom" href="' . home_url( GD_URL_LISTING_ALERTS, 'relative' ) . '">Listing Alerts</a></li>';
					$items .= '<li><a id="gd-my-account-settings-link" class="menu-item menu-item-type-custom menu-item-object-custom" href="' . home_url( GD_URL_ACCOUNT_SETTINGS, 'relative' ) . '">Settings</a></li>';
					$items .= '<li><a id="gd-user-log-out-link" class="menu-item menu-item-type-custom menu-item-object-custom" href="' . home_url( GD_URL_LOG_OUT, 'relative' ) . '">Log Out</a></li>';
				$items .= '</ul>';
			$items .= '</li>';
		}
		else {
			$items .= '<li id="gd-user-login-link"><a href="' . home_url( GD_URL_LOGIN, 'relative' ) . '">Login</a></li>';
		}
	}

	return $items;
}
add_filter( 'wp_nav_menu_items', 'gd_add_nav_menu_items', 10, 2 );
