<?php
$gd_url_options = gd_get_option( GD_OPTIONS_URLS );

// URL paths
define( 'GD_URL_PLUGIN', plugin_dir_url( GD_FILE_MAIN ) );
define( 'GD_URL_ADMIN_ASSETS_CSS', GD_URL_PLUGIN . 'admin/assets/css/' );
define( 'GD_URL_ADMIN_ASSETS_IMAGES', GD_URL_PLUGIN . 'admin/assets/images/' );
define( 'GD_URL_ADMIN_ASSETS_JS', GD_URL_PLUGIN . 'admin/assets/js/' );
define( 'GD_URL_ASSETS_CSS', GD_URL_PLUGIN . 'assets/css/' );
define( 'GD_URL_IMAGES', GD_URL_PLUGIN . 'assets/images/' );
define( 'GD_URL_ASSETS_JS', GD_URL_PLUGIN . 'assets/js/' );

define( 'GD_URL_ACCOUNT', $gd_url_options['AccountPrefix'] );
define( 'GD_URL_ACCOUNT_SETTINGS', $gd_url_options['AccountPrefix'] . 'settings/' );
define( 'GD_URL_ADD_FAVORITE', $gd_url_options['FavoritesPrefix'] . 'add/' );
define( 'GD_URL_ADV_SEARCH', $gd_url_options['ListingsPrefix'] . 'find/' );
define( 'GD_URL_DELETE_FAVORITE', $gd_url_options['FavoritesPrefix'] . 'delete/' );
define( 'GD_URL_DETAILS', $gd_url_options['ListingsPrefix'] . 'home/' );
define( 'GD_URL_DOCUMENT_STORE', $gd_url_options['DocumentStore'] );
define( 'GD_URL_FAVORITES', $gd_url_options['FavoritesPrefix'] );
define( 'GD_URL_FORGOT_PASSWORD', $gd_url_options['AccountPrefix'] . 'forgot-password/' );
define( 'GD_URL_HOME_WORTH', $gd_url_options['HomeWorth'] );
define( 'GD_URL_LISTING_ALERTS', $gd_url_options['ListingAlerts'] );
define( 'GD_URL_LOGIN', $gd_url_options['AccountPrefix'] . 'login/' );
define( 'GD_URL_LOG_OUT', $gd_url_options['AccountPrefix'] . 'log-out/' );
define( 'GD_URL_MORE_INFO', GD_URL_DETAILS . 'more-info/' );
define( 'GD_URL_MORE_INFO_REQUESTED', GD_URL_MORE_INFO . 'requested/' );
define( 'GD_URL_OUR_LISTINGS', $gd_url_options['ListingsPrefix'] . 'our-listings/' );
define( 'GD_URL_PROXY_API_SORT', $gd_url_options['ProxyApi'] . 'sort/' );
define( 'GD_URL_PROXY_API_STATUSES', $gd_url_options['ProxyApi'] . 'statuses/' );
define( 'GD_URL_PROXY_API_STYLES', $gd_url_options['ProxyApi'] . 'styles/' );
define( 'GD_URL_PROXY_API_TYPES', $gd_url_options['ProxyApi'] . 'types/' );
define( 'GD_URL_SEARCH', $gd_url_options['ListingsPrefix'] . 'homes/' );
define( 'GD_URL_SIGNUP', $gd_url_options['AccountPrefix'] . 'signup/' );

// This is used for changing the URLs in the admin settings.
if ( $_SESSION['gd']['flush_rules'] ) {
    add_action( 'init', 'flush_rewrite_rules' );
    unset( $_SESSION['gd']['flush_rules'] );
}

/**
 * Add our custom rewrite rules.
 *
 * @param $rules - Current rules.
 * @return array - New rules.
 */
function gd_add_rewrite_rules( $rules ) {
	$rewrite_rules = array(
		GD_URL_ACCOUNT . '?$'                             => 'index.php?gd_action=account-home', // Account Home
		GD_URL_ACCOUNT_SETTINGS . '?$'                    => 'index.php?gd_action=account-settings', // Account Settings
		GD_URL_ADD_FAVORITE . '?$'                        => 'index.php?gd_action=add-favorite', // Add a favorite
		GD_URL_ADV_SEARCH . '?$'                          => 'index.php?gd_action=advanced-search', // Takes us to the advanced search page
		GD_URL_DELETE_FAVORITE . '?$'                     => 'index.php?gd_action=delete-favorite', // Delete a favorite
  		GD_URL_DETAILS . '([A-Za-z0-9-]*)/(\d+)-(\d+)/?$' => 'index.php?gd_action=details&gd_listing_id=$matches[2]::$matches[3]', // Gives us the details for the selected listing */
		GD_URL_DOCUMENT_STORE . '(\d+)?$'                 => 'index.php?gd_action=download-document&doc_id=$matches[1]', // Download document from document store
		GD_URL_FAVORITES . '?$'                           => 'index.php?gd_action=favorites', // Manage favorites
		GD_URL_FORGOT_PASSWORD . '?$'                     => 'index.php?gd_action=forgot-password', // Allows the user to reset their password via email
		GD_URL_HOME_WORTH . '?$'                          => 'index.php?gd_action=home-worth', // Allows the user to calculate their homeworth
		GD_URL_LISTING_ALERTS . '?$'                      => 'index.php?gd_action=listing-alerts', // Manage Listing Alerts
		GD_URL_LOGIN . '?$'                               => 'index.php?gd_action=login', // Lets users login to their accounts
		GD_URL_LOG_OUT . '?$'                             => 'index.php?gd_action=log-out', // Lets users log out of their accounts
		GD_URL_MORE_INFO . '?$'                           => 'index.php?gd_action=more-info', // Lets users request more information from the realtor
		GD_URL_MORE_INFO_REQUESTED . '?$'                 => 'index.php?gd_action=more-info-requested', // Send request to client and show success message
		GD_URL_OUR_LISTINGS . '?$'                        => 'index.php?gd_action=our-listings', // Show just our listings
		GD_URL_PROXY_API_SORT . '?$'                      => 'index.php?gd_action=proxy-api&api_action=get-sort', // Used to make JS calls to the API for listing sort values
		GD_URL_PROXY_API_STATUSES . '?$'                  => 'index.php?gd_action=proxy-api&api_action=get-statuses', // Used to make JS calls to the API for listing statuses
		GD_URL_PROXY_API_STYLES . '?$'                    => 'index.php?gd_action=proxy-api&api_action=get-styles', // Used to make JS calls to the API for listing styles
		GD_URL_PROXY_API_TYPES . '?$'                     => 'index.php?gd_action=proxy-api&api_action=get-types', // Used to make JS calls to the API for listing types
		GD_URL_SEARCH . '?$'                              => 'index.php?gd_action=search', // Gets us listings that match the search terms
		GD_URL_SIGNUP . '?$'                              => 'index.php?gd_action=signup', // Page for user to signup for favorites, alerts, etc
	);

	return $rewrite_rules + $rules;
}
add_filter( 'rewrite_rules_array', 'gd_add_rewrite_rules' );

#
# WP Custom Query Vars
#
function gd_add_query_vars( $vars ) {
	$vars[] = 'gd_action';
	$vars[] = 'gd_listing_id';
	$vars[] = 'doc_id';
	$vars[] = 'api_action';

	return $vars;
}
add_filter( 'query_vars', 'gd_add_query_vars' );
