<?php
/**
 * Plugin Name: GeoDigs
 * Version: 3.4.1
 * Author: New Media One
 * Author URI: www.newmediaone.net
 * License: GPL2
 */

/*  Copyright 2015  New Media One  (email : support@newmediaone.net )

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

use \GeoDigs\DocumentStore as DocumentStore;
use \GeoDigs\Template as Template;
use \GeoDigs\Router as Router;
use \GeoDigs\API as API;
use \GeoDigs\User as User;

// Wordpress recommends to use this for security.
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

define( 'PROTOCOL', is_ssl() ? 'https://' : 'http://' );

// Admin Settings.
define( 'GD_ADMIN_PAGE', 'geodigs-admin' );
define( 'GD_ADMIN_PAGE_CALENDARS', 'geodigs-calendars' );
define( 'GD_ADMIN_PAGE_DOCUMENT_STORE', 'geodigs-document-store' );
define( 'GD_ADMIN_PAGE_DOMAINS', 'geodigs-domains' );
define( 'GD_ADMIN_PAGE_CUSTOM_SEARCHES', 'geodigs-custom-searches' );
define( 'GD_ADMIN_PAGE_GENERAL', 'geodigs-general' );
define( 'GD_ADMIN_PAGE_USERS', 'geodigs-users' );
define( 'GD_ADMIN_PAGE_SCRIPTS_AND_STYLES', 'geodigs-scripts-styles' );
define( 'GD_ADMIN_PAGE_VALIDATION', 'geodigs-validation' );
define( 'GD_ADMIN_SECTION_ADVANCED_SEARCH', 'advanced-search' );
define( 'GD_ADMIN_SECTION_GENERAL', 'general' );
define( 'GD_ADMIN_SECTION_GOOGLE_MAPS', 'google-maps' );
define( 'GD_ADMIN_SECTION_OUR_LISTINGS', 'our-listings' );
define( 'GD_ADMIN_SECTION_SOCIAL_MEDIA', 'advanced-social-media' );
define( 'GD_ADMIN_SECTION_URLS', 'urls' );
define( 'GD_ADMIN_SECTION_VALIDATION', 'validation' );
define( 'GD_ADMIN_TAB_GENERAL', 'general' );
define( 'GD_ADMIN_TAB_LISTINGS', 'listings' );

define( 'GD_OPTIONS_ADVANCED_SEARCH', 'geodigs_advanced_search' );
define( 'GD_OPTIONS_CUSTOM_SEARCHES', 'geodigs_custom_searches' );
define( 'GD_OPTIONS_GENERAL', 'geodigs_general' );
define( 'GD_OPTIONS_GOOGLE_MAPS', 'geodigs_google_maps' );
define( 'GD_OPTIONS_LOGIN', 'geodigs_login' );
define( 'GD_OPTIONS_OUR_LISTINGS', 'geodigs_our_listings' );
define( 'GD_OPTIONS_SCRIPTS_AND_STYLES', 'geodigs_scripts_and_styles' );
define( 'GD_OPTIONS_SOCIAL_MEDIA', 'geodigs_social_media' );
define( 'GD_OPTIONS_URLS', 'geodigs_urls' );
define( 'GD_OPTIONS_USERS', 'geodigs_users' );
// Store options in array for uninstall.
$gd_options = array(
	GD_OPTIONS_ADVANCED_SEARCH,
	GD_OPTIONS_CUSTOM_SEARCHES,
	GD_OPTIONS_GENERAL,
	GD_OPTIONS_GOOGLE_MAPS,
	GD_OPTIONS_LOGIN,
	GD_OPTIONS_OUR_LISTINGS,
	GD_OPTIONS_SCRIPTS_AND_STYLES,
	GD_OPTIONS_SOCIAL_MEDIA,
	GD_OPTIONS_URLS,
	GD_OPTIONS_USERS,
);

require_once 'functions/core.php';
require_once 'functions/format.php';
require_once 'functions/helper.php';
require_once 'functions/login.php';

require_once 'classes/API.php';
require_once 'classes/Calendars.php';
require_once 'classes/CustomSearches.php';
require_once 'classes/DocumentStore.php';
require_once 'classes/Template.php';
require_once 'classes/User.php';

// Files aren't always included from the correct directory so this makes sure we do.
$this_dir = dirname( __FILE__ );
$gd_directory
	= file_exists( $this_dir . '/geodigs.php' ) ? $this_dir . '/' : '';
define( 'GD_DIR', $gd_directory );
define( 'GD_DIR_ADMIN', GD_DIR . 'admin/' );
define( 'GD_DIR_ADMIN_ASSETS', GD_DIR_ADMIN . 'assets/' );
define( 'GD_DIR_ADMIN_INCLUDES', GD_DIR_ADMIN . 'includes/' );
define( 'GD_DIR_ADMIN_TEMPLATES', GD_DIR_ADMIN . 'templates/' );
define( 'GD_DIR_ASSETS', GD_DIR . 'assets/' );
define( 'GD_DIR_CSS', GD_DIR_ASSETS . 'css/' );
define( 'GD_DIR_EMAILS', GD_DIR . 'emails/' );
define( 'GD_DIR_IMAGES', GD_DIR_ASSETS . 'images/' );
define( 'GD_DIR_INCLUDES', GD_DIR . 'includes/' );
define( 'GD_DIR_JS', GD_DIR_ASSETS . 'js/' );
define( 'GD_DIR_MODALS', GD_DIR . 'modals/' );
define( 'GD_DIR_THEMES', GD_DIR . 'themes/' );
define( 'GD_DIR_WIDGETS', GD_DIR . 'widgets/' );
define( 'GD_FILE_MAIN', __FILE__ );

// Block bad bots.
$spiders = array(
	'pcore-http',
	'yandex.com',
	'Baiduspider',
	'majestic12',
	'Semrush',
);
$useragent = strtolower($_SERVER['HTTP_USER_AGENT']);
foreach ( $spiders as $bot ) {
    if ( preg_match( "/$bot/i", $useragent ) ) {
		include_once GD_DIR_INCLUDES . 'bad-bot.php';
		exit;
	}
}

// Get the login info, defaults to the demo info.
$login_info = gd_get_option( 'geodigs_login' );
if ( isset( $login_info['Status'] ) ) {
	if ( $login_info['Status'] == 'success' || $login_info['Status'] == 'demo' ) {
		// Start our session
		session_start();

        ///////////////////////////////////////////////////////////////////////        
        ///////////////////////////////////////////////////////////////////////        
        ///////////////////////////////////////////////////////////////////////        
        // UNCOMMENT TO RESET SESSION
        ///////////////////////////////////////////////////////////////////////        
        ///////////////////////////////////////////////////////////////////////        
        ///////////////////////////////////////////////////////////////////////        
        unset( $_SESSION['gd']['agent'] );
        unset( $_SESSION['gd_user'] );

		define( 'GD_LOGIN_STATUS', $login_info['Status'] );
	} else {
		define( 'GD_LOGIN_STATUS', 'invalid' );
	}
} else {
	define( 'GD_LOGIN_STATUS', 'not_logged_in' );
}

// If there is no API key stored (login or temp key) then generate a new temporary one.
$key = User::get_api_key();
if ( false == $key && isset( $login_info['AgentCode'] )) {
	User::login_temp( $login_info['AgentCode'] );
} else {
	API::set_key( $key );
}
unset($key);

// If our info is valid make sure our agent is stored in the session.
if ( GD_LOGIN_STATUS == 'success' || GD_LOGIN_STATUS == 'demo' ) {
	// Attempt to login (two attempts)
	$logged_in = gd_try_login();

	if ( $logged_in ) {
		// Max Detail Views
		if ( false == isset( $general_options ) ) {
			$general_options = gd_get_option( GD_OPTIONS_GENERAL );
		}
		$_SESSION['gd']['agent']->max_detail_views = $general_options['MaxDetailViews'];
	} else {
        $error = 'API Response: ' . print_r($_SESSION['gd']['agent'], true) .
                 "\nAPI Key: " . API::get_key();
        $message = array(
            'There was an error during user login on ' . home_url(),
            $error
        );

        error_log( $error );
		mail( 'support@newmediaone.net',
			'GeoDigs Site Error',
			$message );

		wp_die( 'GeoDigs: There has been an error.  Please try again or check back later.', 'GeoDigs Error' );
	}
}

require_once 'functions/urls.php';
register_activation_hook( __FILE__, 'flush_rewrite_rules' );

require_once 'functions/enqueue-scripts.php';
require_once 'functions/enqueue-styles.php';
require_once 'functions/dequeue-scripts-and-styles.php';

if ( is_admin() ) {
	require_once 'admin/index.php';
} else {
	require_once 'classes/Router.php';
	require_once 'functions/navigation.php';
}

require_once 'widgets/_init.php';
require_once 'shortcodes/_init.php';
