<?php
use GeoDigs\API as API;
use GeoDigs\Template as Template;
use GeoDigs\User as User;

$show_searches = true;
if ( isset( $_GET['action'] ) ) {
	switch ( $_GET['action'] ) {
		case 'add':
			if ( isset( $_POST['search_name'] ) ) {
				// Add new search
				if ( User::add_search() ) {
					$success = 'Your alert has been saved.';
				}
				else {
					$error = 'Your alert could not be saved.';
				}
			}
			break;

		case 'edit':
			$page_title  = 'Edit Listing Alert';
			$search      = User::get_search( $_GET['search_id'] );
			$form_action = home_url( '/' . GD_URL_LISTING_ALERTS . '?action=update&search_id=' . $_GET['search_id'] );
			$show_searches = false;
			break;

		case 'update':
			if ( isset( $_POST['search_name'] ) ) {
				// We lose our POST data when we delete the search so make sure we save it
				User::delete_search( $_GET['search_id'] );
				if ( User::add_search() ) {
					$success = 'Your alert has been updated.';
				}
				else {
					$error = 'Your alert could not be updated.';
				}
			}
			break;

		case 'delete':
			if ( User::delete_search( $_GET['search_id'] ) ) {
				$success = 'Your alert has been deleted.';
			}
			else {
				$error = 'Your alert could not be deleted.';
			}
			break;
	}
}

if ( $show_searches ) {
	$show_instruct = true;
	$page_title    = 'Listing Alerts';
	$form_action   = home_url( '/' . GD_URL_LISTING_ALERTS . '?action=add' );
	User::get_searches( 'array' );
}

// We use post for listing alerts
$form_method        = 'post';
$form_submit        = 'Save';
$listing_alert_form = true;

// Get data to populate fields with
$listing_types    = API::call( "GET", "listings/types" );
$listing_statuses = API::call( "GET", "listings/statuses" );
$listing_styles   = API::call( "GET", "listings/styles" );
// For now this is hardcoded but if we decide to add this function to the API then replace the array with the API call
$listing_levels   = array(
	( object ) array(
		'id' => 'Main',
		'readable' => 'Main',
	),
	( object ) array(
		'id' => 'Upper',
		'readable' => 'Upper',
	),
	( object ) array(
		'id' => 'Basement',
		'readable' => 'Basement',
	),
	( object ) array(
		'id' => 'Lower',
		'readable' => 'Lower',
	),
	( object ) array(
		'id' => 'Other Finished SqFt',
		'readable' => 'Other Finished SqFt',
	),
);
$cities = gd_get_cities();

// If our current city isn't in the list of available cities, add it to the front
if ( isset( $_GET['cities'] ) && !in_array( $_GET['cities'], ( array ) $cities ) ) {
	array_unshift( $cities, ( object ) array( 'name' => $_GET['cities'] ) );
}


// Enqueue scripts and styles
$adv_search_settings = gd_get_option( GD_OPTIONS_ADVANCED_SEARCH );
wp_localize_script( 'gd_map_search', 'map_search', array(
	'start' => array(
		'lat' => $adv_search_settings['MapSearchStartLat'],
		'lon' => $adv_search_settings['MapSearchStartLon'],
		'zoom' => $adv_search_settings['MapSearchStartZoom'],
	),
));
wp_enqueue_script( 'gd_map_search' );
wp_enqueue_style( 'gd_map' );
?>

<!-- Notifcations -->
<?php if ( isset( $success ) && !empty( $success ) ): ?>
	<div class="alert alert-success" role="alert">
		<p><?=$success?></p>
	</div>
<?php endif; ?>
<?php if ( isset ( $error ) && !empty( $error ) ): ?>
	<div class="alert alert-danger" role="alert">
		<p><?=$error?></p>
	</div>
<?php endif; ?>

<!-- Existing alerts -->
<?php $listing_alerts_count = count( $_SESSION['gd']['user']->searches ); ?>
<?php if ( $listing_alerts_count > 0 ): ?>
	<div class="gd-saved-listing-alerts">
		<h2>Saved Alerts ( <?=$listing_alerts_count?> )</h2>
		<?php
		$sr = 0;
		foreach( $_SESSION['gd']['user']->searches as $search ) {
			// If there is no id this isn't a real search
			if ( !$search->id ) {
				continue;
			}

			$search_link = home_url( '/' . GD_URL_SEARCH . '?' . http_build_query( $search->params ) );
			$edit_link   = home_url( '/' . GD_URL_LISTING_ALERTS . '?action=edit&search_id=' . $search->id );
			$remove_link = home_url( '/' . GD_URL_LISTING_ALERTS . '?action=delete&search_id=' . $search->id );

			include GD_DIR_INCLUDES . 'listing-alerts-row.php';
		} ?>
	</div>
<?php endif; ?>
<!-- /Existing alerts -->
<br>

<!-- Create new alert -->
<div id="gd-create-listing-alert">
<!-- 	Instruction text -->
	<?php if ( $show_instruct ): ?>
		<h2>
			To Create New Listing Alerts
			<small>
				start by naming your search below and then filling out the applicable fields and selecting "Save Alert."
			</small>
		</h2>
	<?php endif; ?>

	<?php
	gd_set_search_params( $search->params );
	Template::load(
		'search-forms/advanced.php',
		array(
			'form_action'        => $form_action,
			'form_method'        => $form_method,
			'form_submit'        => $form_submit,
			'listing_alert_form' => $listing_alert_form,
			'search'             => $search,
			'cities'             => $cities,
			'listing_levels'     => $listing_levels,
		)
	); ?>
</div>
<!-- /Create new alert -->
