<?php use \GeoDigs\API as API; ?>
<?php use \GeoDigs\Template as Template; ?>
<?php use \GeoDigs\User as User; ?>

<!-- START: listing-results.php -->
<div id="gd" class="gd-results">
	<?php
	// Prepare the JS data to be passed
	$latitudes     = array();
	$longitudes    = array();
	$map_previews  = array();
	$listings      = $results->listings;
	$listing_count = count( $listings );

	if ( isset( $listings ) && $listing_count > 0 ) {
		$last_updated = API::call('GET', 'listings/updated' );

		// Get layout settings
		if ( !isset( $layout ) ) {
			$general_options = get_option( GD_OPTIONS_GENERAL );
			$layout          = '';
			// If our layout is 'rows' then we are using the dsIDX layout
			if ( isset( $general_options['ListingsLayout'] ) && $general_options['ListingsLayout'] != 'rows' ) {
				$layout = '-' . $general_options['ListingsLayout'];
			}
		}

		/** PAGINATION **/
		ob_start();
		include_once GD_DIR_INCLUDES . 'listings-pagination.php';
		$pagination = ob_get_clean();

		$listings_start = isset( $results->pagination->currentListings->start->readable ) ?
			$results->pagination->currentListings->start->readable :
			'';
		$listings_end = isset( $results->pagination->currentListings->end->readable ) ?
			$results->pagination->currentListings->end->readable :
			'';
		$listings_total = isset( $results->pagination->totalListings->readable ) ?
			$results->pagination->totalListings->readable :
			'';
		/** END PAGINATION **/

		/** HEADER **/
		$sorts = API::call('GET', 'listings/sort');
		ob_start(); ?>

		<option value="">None</option>
		<?php foreach ( $sorts as $sort ): ?>
			<?php
			$value     = $sort->id;
			$sort_vals = explode('::', $value);
			$selected  = $_GET['orderBy'] == $sort_vals[0] && $_GET['orderByDirection'] == $sort_vals[1] ? 'selected' : '';
			?>
			<option value="<?=$value?>" <?=$selected?>><?=$sort->readable?></option>
		<?php endforeach; ?>

		<?php
		$sort_options = ob_get_clean();

		// Output listings header template
		Template::load(
			'listings/header.php',
			array(
				'show_map'         => isset( $show_map ) ? $show_map : true,
				'show_edit_search' => isset( $show_edit_search ) ? $show_edit_search : true,
				'show_sort'        => isset( $show_sort ) ? $show_sort : true,
				'show_count'       => isset( $show_count ) ? $show_count : true,
				'sort_options'     => $sort_options,
				'edit_search_link' => home_url( '/' . GD_URL_ADV_SEARCH . '?' . $_SERVER['QUERY_STRING'] . ( empty( $_SERVER['QUERY_STRING'] ) ? 'edit_search=true' : '&edit_search=true' ) ),
				'save_search_link' => home_url( '/' . GD_URL_LISTING_ALERTS . '?' . $_SERVER['QUERY_STRING'] ),
				'listings_start'   => $listings_start,
				'listings_end'     => $listings_end,
				'listings_total'   => $listings_total,
				'pagination'       => $pagination,
			)
		);
		/** END HEADER **/

		/** LISTINGS **/
		$listing_results = '';
		$count           = 0;
		foreach ( $listings as $listing ) {
			// Get photo
			// $photo       = API::URL . "listings/{$listing->id}/photo/0?size=small";
			// $photo_large = API::URL . "listings/{$listing->id}/photo/0?size=large";
			$images_url = 'http://images.geodigs.com/%s/image.jpg?%s';
			$source = $listing->source->id;
			$photo_small_data = array(
				'id' => $listing->mlsNumber,
				'w' => 224,
			);
			$photo_large_data = array(
				'id' => $listing->mlsNumber,
				'w' => 1080,
			);
			$photo = sprintf(
				$images_url,
				$source,
				http_build_query( $photo_small_data )
			);
			$photo_large = sprintf(
				$images_url,
				$source,
				http_build_query( $photo_large_data )
			);

			// Get the address and URL
			$address = isset( $listing->address->readable )
				? $listing->address->readable : 'No Address';
			$listing_url = gd_format_listing_url( $address, $listing->id );

			// Get favorite status
			$favorite_status = User::has_favorite( $listing->id ) ? 'gd-favorite-toggle-on' : '';

			// Add map coords. for JS data
			array_push( $latitudes, $listing->coords->lat );
			array_push( $longitudes, $listing->coords->lon );

			// Add map preview for JS data
			array_push(
				$map_previews,
				Template::load(
					'listings/map-preview.php',
					array(
						'listing'     => $listing,
						'listing_url' => $listing_url,
						'photo'       => $photo,
					),
					false
				)
			);

			// Load the listing result template
			switch ( $general_options['ListingsLayout'] ) {
				// DEPRICATED
				case 'columns-2':
					$template = 'listings/columns-2.php';
					break;
				// END DEPRICATED

				case 'grid':
					$template = 'listings/grid.php';
					break;

				case 'rows':
				default;
					$template = 'listings/row.php';
					break;
			}
			$listing_results .= Template::load(
				$template,
				array(
					'listing'         => $listing,
					'address'         => $address,
					'listing_url'     => $listing_url,
					'photo'           => $photo,
					'photo_large'     => $photo_large,
					'favorite_status' => $favorite_status,
					'loop_count'      => $count,
				),
				false
			);

			$count++;
		}

		// Load listing results template
		Template::load(
			'listings/results.php',
			array(
				'layout'          => $layout,
				'listing_results' => $listing_results,
			)
		);
		/** END LISTINGS **/

		/** FOOTER **/
		Template::load(
			'listings/footer.php',
			array(
				'pagination' => $pagination,
				'last_updated' => $last_updated->readable,
			)
		);
		/** END FOOTER **/


		// Get the info to setup our map view radii
		$center_listing    = $listing_count / 2;
		$center_lon_radius = $longitudes[$center_listing];
		$center_lat_radius = $latitudes[$center_listing];

		wp_localize_script( 'gd_map_results', 'map_results', array(
			'latitudes'         => $latitudes,
			'longitudes'        => $longitudes,
			'map_previews'      => $map_previews,
			'listing_count'     => $listing_count,
			'center_lon_radius' => $center_lon_radius,
			'center_lat_radius' => $center_lat_radius,
		));
		wp_enqueue_script( 'gd_map_results' );
	}
	else {
		echo '<h2>No listings found</h2>';
	} ?>
</div>
<!-- END: listing-results.php -->
