<?php
namespace GeoDigs\Shortcodes;

use GeoDigs\API as API;
use GeoDigs\Template as Template;

/**
 * GeoDigs Advanced Search shortcode
 */
class AdvancedSearch extends Shortcode
{

	function __construct() {
		$this->handle = 'gd_advanced_search';

		parent::__construct( $this->handle );
	}

	public function handle_shortcode( $atts ) {
		// Get data to populate fields with
		// For now this is hardcoded but if we decide to add this function to the API then replace the array with the API call
		$listing_levels = API::call('GET', 'listings/rooms/levels');
		$cities = gd_get_cities();

		// Get default listing type

		// If our current city isn't in the list of available cities, add it to the front
		if ( isset( $_GET['cities'] ) && !in_array( $_GET['cities'], ( array ) $cities ) ) {
			array_unshift( $cities, ( object ) array( 'name' => $_GET['cities'] ) );
		}

		// Form is used to search through listings
		$form_action        = home_url( '/' . GD_URL_SEARCH );
		$form_method        = 'get';
		$form_submit        = 'Search';
		$listing_alert_form = false;

		// Set our params to the get string params
		gd_set_search_params( $_GET );

		ob_start();
		?>
		<div class="gd-advanced-search">
			<?php
			Template::load(
				'search-forms/advanced.php',
				array(
					'form_action'        => $form_action,
					'form_method'        => $form_method,
					'form_submit'        => $form_submit,
					'listing_alert_form' => $listing_alert_form,
					'cities'             => $cities,
					'listing_levels'     => $listing_levels,
				)
			);
			?>
		</div>
		<?php
		$content = ob_get_clean();
		return $content;
	}

	public function enqueue_scripts() {
		global $post;

		if( is_a( $post, 'WP_Post' ) && has_shortcode( $post->post_content, $this->handle ) ) {

			$adv_search_settings = gd_get_option( GD_OPTIONS_ADVANCED_SEARCH );
			wp_localize_script( 'gd_map_search', 'map_search', array(
				'start' => array(
					'lat' => $adv_search_settings['MapSearchStartLat'],
					'lon' => $adv_search_settings['MapSearchStartLon'],
					'zoom' => $adv_search_settings['MapSearchStartZoom'],
				),
			));

			wp_enqueue_script( 'gd_map_search' );
			wp_enqueue_style( 'gd_map' );
		}
	}
}
