<?php
namespace GeoDigs\Shortcodes;

use \GeoDigs\API as API;
use \GeoDigs\Template as Template;
use \GeoDigs\User as User;

/**
 * GeoDigs Custom Search shortcode
 */
class CustomSearch extends Shortcode
{

	function __construct() {
		$this->handle = 'gd_custom_search';

		parent::__construct( $this->handle );

		// For backwards compatability
		add_shortcode( 'gd_featured_group', array( &$this, 'handle_shortcode' ) ); // DEPRICATED, ALIAS FOR gd_custom_search
	}

	public function handle_shortcode( $atts ) {
		$a = shortcode_atts( array(
			'id' => null,
		), $atts );

		$search = API::call( 'GET', "searches/custom/{$a['id']}" );
		if ( !isset( $search->error ) ) {
			$data = (array) $search->params->general;

			// sort
			if ( isset( $search->sort->value ) && !empty( $search->sort->value ) ) {
				$order = explode( '::', $search->sort->value );
			}
			// If the GET params orderBy and orderByDirection are not set,
			// set them to our default sort order
			if ( !isset( $_GET['orderBy'] ) ) {
				$_GET['orderBy'] = $order[0];
			}
			if ( !isset( $_GET['orderByDirection'] ) ) {
				$_GET['orderByDirection'] = $order[1];
			}
			$data['orderBy'] = $_GET['orderBy'];
			$data['orderByDirection'] = $_GET['orderByDirection'];

			#GROUP properties
			if ( isset( $search->params->properties ) ) {
				$data['properties'] = $search->params->properties->value;
			}

			#GROUP: agents
			if ( isset( $search->params->agents ) ) {
				if ( isset( $search->params->agents->list ) ) {
					unset( $search->params->agents->list );
				}
				$data['agents'] = (array) $search->params->agents;
			}

			#GROUP: offices
			if ( isset( $search->params->offices ) ) {
				if ( isset( $search->params->offices->list ) ) {
					unset( $search->params->offices->list );
				}
				$data['offices'] = (array) $search->params->offices;
			}

			// other
			$data['limit']    = $search->displayCount;
			$data['fill']    = $search->fill;
			$data['featured'] = true;

			// Check if we are requesting a certain page
			if ( isset( $_GET['listingsPage'] ) ) {
				$data['page'] = (int) $_GET['listingsPage'];
			}

			// API::enable_debug();
			$results = API::call( 'GET', 'listings', $data );
			// print_r($results->debug);
			// exit;

			// Ensures backwards compatability.
			// The database value for the featured template used to be 'default'
			// so this makes sure that older sites still work with this
			$template = $search->layout == 'default' ? 'featured' : $search->layout;

			if ( $template == 'featured' ) {
				$listings = $results->listings;
				if( $listings ) {

					$count = 0;
					return Template::load(
						"listings/{$template}.php",
						array(
							'title'    => $search->name,
							'listings' => $listings,
							'count'    => $count,
						),
						false
					);
				} else {
					return '';
				}
			} else {
				// Start the output
				$hide_edit_search = true;
				$show_map = isset( $search->showMap ) ? (bool) $search->showMap : false;
				ob_start();

				include_once GD_DIR_INCLUDES . 'listings-results.php';

				return ob_get_clean();
			}

		} else {
			echo 'GeoDigs Error: Could not get custom search ' . $a['id'] . ' - ' . $search->message;
		}
	}

	public function enqueue_scripts() {}
}
