<?php
/**
 * NOTES
 *
 * 	- gd_create_table_str( $array ) takes an array of key=>val pairs and
 * 		outputs them to a formatted table
 * 	- $last_updated comes from the plugin core files and
 * 		must be included on this page
 *	- To view all available data points call var_dump( $listing )
 */

// Enqueue scripts and styles
function gd_enqueue_detail_styles() {
	wp_enqueue_script( 'gd_slider' );
	wp_enqueue_style( 'royalslider' );
}
add_action( 'wp_enqueue_scripts', 'gd_enqueue_detail_styles' );

// General Features
$general = array(
	'MLS'               => $listing->mlsNumber,
	'Status'            => $listing->status->readable,
	'Listing Office'    => $listing->office->name->value,
/* 	'Type'              => $listing->type->value, */
	'Style'             => $listing->style->value,
	'Construction'      => $listing->construction->value,
	'Bedrooms'          => $listing->beds->count,
	'Baths'             => $listing->baths->count,
	'Cooling'           => $listing->cooling->value,
	'Heating'           => $listing->heating->value,
	'Total SqFt'        => $listing->sizes->total->area->readable,
	'Finished SqFt'     => $listing->sizes->finished->area->readable,
	'Above Ground SqFt' => $listing->sizes->aboveGround->area->readable,
	'Acreage'           => $listing->sizes->acreage->area->readable,
	'Lot Size'          => $listing->sizes->lot->area->readable,
	'Year Built'        => $listing->yearBuilt->value,
);

// Room Sizes
$rooms = array(
/* 	'Main Floor' => $listing->sizes->mainFloor->area->readable, */
	'Office/Study' => $listing->rooms->study->readable,
	'Dining Room' => $listing->rooms->dining->readable,
	'Laundry Room' => $listing->rooms->laundry->readable,
	'Kitchen' => $listing->rooms->kitchen->readable,
	'Living Room' => $listing->rooms->living->readable,
	'Rec Room' => $listing->rooms->rec->readable,
	'Family Room' => $listing->rooms->family->readable,
	'Great Room' => $listing->rooms->great->readable,
	'Master Bedroom' => $listing->rooms->masterBed->readable,
	'Bedroom 2' => $listing->rooms->bed2->readable,
	'Bedroom 3' => $listing->rooms->bed3->readable,
	'Bedroom 4' => $listing->rooms->bed4->readable,
	'Bedroom 5' => $listing->rooms->bed5->readable,
);

// School Information
$schools = array(
	'District' => $listing->schools->district->value,
	'Elementary' => $listing->schools->elementary->value,
	'Middle' => $listing->schools->middle->value,
	'High' => $listing->schools->high->value,
);

// Taxes & Fees
$taxes = array(
	'Tax Amount' => $listing->taxes->taxAmount->readable,
	'Tax Year'   => $listing->taxes->taxYear,
);
$fees = array();
if ( isset( $listing->fees ) ) {
	foreach ( $listing->fees as $fee ) {
		$fees[$fee->name] = $fee->readable;
	}
}

// Additional Information
$additional = array();
if ( isset( $listing->additional ) ) {
	foreach ( $listing->additional as $addition ) {
		$additional[$addition->readable] = $addition->value;
	}
}
if ( isset( $listing->features ) ) {
	foreach ( $listing->features as $feature ) {
		$additional[$feature->readable] = $feature->value;
	}
}

$source_disclaimer = isset( $listing->source )
	? $listing->source->disclaimer
	: '';
$source_image = isset( $listing->source ) ? $listing->source->image : '';
?>

<header class="gd-details-header row gd-row">
	<div class="gd-col-md-4 col-md-4">
		<?php if ( $_SERVER['HTTP_REFERER'] ): ?>
			<a class="gd-back-to-search-btn" href="<?php echo esc_url( $_SERVER['HTTP_REFERER'] ); ?>">Back to search results</a>
			<br>
		<?php endif; ?>
		<h1 class="gd-listing-title"><?php echo $listing->price->readable; ?>
			<?php if ( $listing->beds ): ?>
				<br>
				<?php echo $listing->beds->readableLong; ?>
			<?php endif; ?>
			<?php if ( $listing->beds && $listing->baths ): ?>
				,
			<?php endif; ?>
			<?php if ( $listing->baths ): ?>
				<?php echo $listing->baths->readableLong; ?>
			<?php endif; ?>
		</h1>
<!-- 		Actions -->
		<div class="gd-actions">
			<a href="<?php gd_create_listing_url( $listing, 'echo' ); ?>" class="gd-links-button">
				<div>
					<?php echo file_get_contents( GD_DIR_IMAGES . 'ui/email.svg' ); ?>
					<span>Contact <?php echo $_SESSION['gd']['agent']->name->first; ?></span>
				</div>
			</a>
			<a href="" class="gd-links-button modal-open" data-toggle="modal" data-target="#gd-mortgage-calc-modal">
				<div>
					<input type="hidden" id="gd-mortgage-calculator-price-val" value="<?php echo $listing->price->readable; ?>">
					<input type="hidden" id="gd-mortgage-calculator-taxes-val" value="<?php echo $listing->taxes->taxAmount->readable; ?>">
					<?php echo file_get_contents( GD_DIR_IMAGES . 'ui/calculator.svg' ); ?>
					<span>Mortgage Calculator</span>
				</div>
			</a>
			<a href="/<?php echo GD_URL_SEARCH?>?lat=<?php echo $listing->coords->lat; ?>&lon=<?php echo $listing->coords->lon; ?>&radius=1" class="gd-links-button">
				<div>
					<?php echo file_get_contents( GD_DIR_IMAGES . 'ui/search.svg' ); ?>
					<span>Nearby Properties</span>
				</div>
			</a>
			<a href="#" class="gd-links-button modal-open" data-toggle="modal" data-target="#gd-map-it-modal">
				<div>
					<?php echo file_get_contents( GD_DIR_IMAGES . 'ui/map-pin.svg' ); ?>
					<span>Map It</span>
				</div>
			</a>
			<?php if ( \GeoDigs\User::is_logged_in() ): ?>
				<a>
					<div class="gd-favorite-toggle <?php echo $favorite_status?>" data-listing-id="<?php echo $listing->id?>">
						<?php echo file_get_contents( GD_DIR_IMAGES . 'ui/favorite-star.svg' ); ?>
						<span class="gd-favorite-add-text">Add Favorite</span>
						<span class="gd-favorite-remove-text">Remove Favorite</span>
					</div>
				</a>
			<?php endif; ?>
		</div>
	</div>
	<div class="col-md-8 gd-col-md-8">
		<div class="royalSlider rsDefault">
			<?php if ( $listing->photoCount > 0 ): ?>
				<?php for ( $i = 0; $i < $listing->photoCount; $i++ ): ?>
					<?php
					$photo_large = gd_create_listing_image_url(
						$listing, $i, 'large' );
					$photo_fullscreen = gd_create_listing_image_url(
						$listing, $i, 'fullscreen' );
					$caption = isset( $listing->photos->{$i} ) ? $listing->photos->{$i}->caption : '';
					?>
					<a class="rsImg" href="<?php echo $photo_large; ?>" data-rsBigImg="<?php echo $photo_fullscreen; ?>"><?php echo $caption; ?></a>
				<?php endfor; ?>
			<?php endif; ?>
		</div>
	</div>

	<div class="col-md-12 gd-col-md-12">
		<!-- 		Description -->
		<?php if( $listing->description ): ?>
			<div id="gd-description">
				<h3>Property Description</h3>
				<span>
					<?php echo $listing->description; ?>
				</span>
			</div>
		<?php endif; ?>
	</div>
</header>
<div class="row gd-row">
<!-- 		General Features -->
	<div id="gd-general-feat" class="col-md-6 gd-col-md-6">
		<h1>General Features</h1>
		<?php echo gd_create_table_str( $general ); ?>
	</div>

<!-- 		Room Sizes -->
	<?php if ( $listing->rooms || $listing->sizes->mainFloor ): ?>
		<div id="gd-room-sizes" class="col-md-6 gd-col-md-6">
			<h1>Room Sizes</h1>
			<?php echo gd_create_table_str( $rooms ); ?>
		</div>
	<?php endif; ?>

<!-- 		Schools -->
	<?php if( $listing->schools ): ?>
		<div id="gd-school-info" class="col-md-6 gd-col-md-6">
			<h1>School Information</h1>
			<?php echo gd_create_table_str( $schools, 1 ); ?>
		</div>
	<?php endif; ?>

<!-- 		Taxes -->
	<?php if( $listing->taxes || $listing->fees ): ?>
		<div id="gd-taxes" class="col-md-6 gd-col-md-6">
			<h1>Taxes & Fees</h1>
			<?php if ( $listing->taxes ) echo gd_create_table_str( $taxes, 1 ); ?>
			<?php if ( $listing->fees ) echo gd_create_table_str( $fees, 1 ); ?>
		</div>
	<?php endif; ?>

<!-- 		Additional Information -->
	<?php if ( count( $additional ) > 0 ): ?>
		<div id="gd-additional-info" class="col-xs-12 gd-col-xs-12">
			<h1>Additional Information</h1>
			<?php echo gd_create_table_str( $additional, 1 ); ?>
		</div>
	<?php endif; ?>
</div>

<footer class="gd-details-footer">
	<!-- REQUIRED -->
	<div class="gd-last-updated">
		Property Database Last Updated: <?php echo $last_updated; ?>
	</div>
	<div class="gd-disclaimer">
		<p><img src="<?php echo $source_image; ?>" alt="IDX Source"> <?php echo $source_disclaimer; ?></p>
	</div>
	<!-- END REQUIRED -->
</footer>

<!-- Load the modals used here -->
<?php include_once GD_DIR_MODALS . 'mortgage-calculator.php'; ?>
<?php include_once GD_DIR_MODALS . 'map-single.php'; ?>
